(function() {
	'use strict';
	window.BBTabs = {
		setupTabs: function() {
			var btTabWraps = document.querySelectorAll('.bt-tabs-wrap');
			btTabWraps.forEach((thisElem) => {

				thisElem.querySelectorAll(':scope > .bt-tabs-title-list').forEach((subElem) => {
					subElem.setAttribute('role', 'tablist');
				});
				thisElem.querySelectorAll(':scope > .bt-tabs-content-wrap > .bt-tab-inner-content').forEach((subElem) => {
					subElem.setAttribute('role', 'tabpanel');
					subElem.setAttribute('aria-hidden', 'true');
				});

				thisElem.querySelectorAll(':scope > .bt-tabs-title-list li a').forEach((subElem) => {
					var parentListItem = subElem.parentElement;
					var parentId = parentListItem.getAttribute("id");
					var isActive = parentListItem.classList.contains('bt-tab-title-active');

					parentListItem.setAttribute('role', 'presentation');
					subElem.setAttribute('role', 'tab');
					// subElem.setAttribute('aria-controls', parentId);
					subElem.setAttribute('aria-selected', isActive ? 'true' : 'false');
					subElem.setAttribute('tabindex', isActive ? '0' : '-1');

					// Set attr on the related content tab
					var tabId = subElem.getAttribute('data-tab');
					var contentTab = thisElem.querySelector(':scope > .bt-tabs-content-wrap > .bt-inner-tab-' + tabId);
					contentTab.setAttribute('aria-labelledby', parentId);
					contentTab.setAttribute('aria-hidden', isActive ? 'false' : 'true');

					if( isActive ){
						contentTab.style.display = 'block';
					}
				});

				thisElem.querySelectorAll(':scope > .bt-tabs-title-list li').forEach((listItem) => {
					listItem.addEventListener('keydown', function(evt) {
						//const listItem = this.parentElement;
						switch ( evt.which ) {
							case 37:
								if ( listItem.previousElementSibling ) {
									listItem.previousElementSibling.querySelector('a').click();
								} else {
									listItem.parentElement.querySelector('li:last-of-type > a' ).click();
								}
								break;
							case 39:
								if (listItem.nextElementSibling) {
									listItem.nextElementSibling.querySelector('a').click();
								} else {
									listItem.parentElement.querySelector('li:first-of-type > a' ).click();
								}
								break;
						}
					});
				});
				var resizeEvent = new Event('resize');
				window.dispatchEvent(resizeEvent);
			});

			var btTabButtons = document.querySelectorAll('.bt-tabs-title-list li a');
			btTabButtons.forEach((thisElem) => {
				thisElem.addEventListener('click', function(evt) {
					evt.preventDefault();
					const newActiveTabId = thisElem.getAttribute('data-tab');
					const tabWrap = thisElem.closest('.bt-tabs-wrap');
					window.BBTabs.setActiveTab(tabWrap, newActiveTabId);
				});
			});

			var btAccordions = document.querySelectorAll('.bt-create-accordion');
			btAccordions.forEach((thisElem) => {
				thisElem.querySelectorAll(':scope > .bt-tabs-title-list .bt-title-item').forEach((listItem) => {
					var tabId = listItem.querySelector('a').getAttribute('data-tab');

					var titleClasses = listItem.classList;
					var accordionTitleClasses = [
						'bt-tabs-accordion-title',
						'bt-tabs-accordion-title-' + tabId
					]

					const closestTabWrap = listItem.closest('.bt-tabs-wrap');
					const btContentWrap = closestTabWrap.querySelector(':scope > .bt-tabs-content-wrap');

					const newElem = window.document.createElement('div');
					newElem.className = [...titleClasses].concat(accordionTitleClasses).join(' ');
					newElem.innerHTML = listItem.innerHTML;

					btContentWrap.insertBefore(newElem, btContentWrap.querySelector(':scope > .bt-inner-tab-' + tabId));

					btContentWrap.querySelector(':scope > .bt-tabs-accordion-title-' + tabId + '  a').removeAttribute('role');
					btContentWrap.querySelector(':scope > .bt-tabs-accordion-title-' + tabId + '  a').removeAttribute('tabindex');
				});
			});

			var btAccordionAnchor = document.querySelectorAll('.bt-tabs-accordion-title a');
			btAccordionAnchor.forEach((thisElem) => {
				thisElem.addEventListener('click', function(evt) {

					evt.preventDefault();

					var tabId = thisElem.getAttribute('data-tab');
					var accTitle = thisElem.parentElement;
					var tabWrap = thisElem.closest('.bt-tabs-wrap');
					var tabContent = tabWrap.querySelector(':scope > .bt-tabs-content-wrap > .bt-inner-tab-' + tabId);

					if ( accTitle.classList.contains( 'bt-tab-title-active' ) ) {
						tabWrap.classList.remove('bt-active-tab-' + tabId);
						accTitle.classList.replace('bt-tab-title-active', 'bt-tab-title-inactive');
						tabContent.style.display = 'none';
					} else {
						tabWrap.classList.add('bt-active-tab-' + tabId);
						accTitle.classList.replace('bt-tab-title-inactive', 'bt-tab-title-active');
						tabContent.style.display = 'block';
					}

					var resizeEvent = new Event('resize');
					window.dispatchEvent(resizeEvent);
					var tabEvent = new Event('base-tabs-open');
					window.dispatchEvent(tabEvent);
				});
			});
			window.BBTabs.setActiveWithHash();
		},
		setActiveWithHash: function() {
			if ( window.location.hash == '' ) {
				return;
			}

			var tabTitleItems = window.document.querySelector(window.location.hash + '.bt-title-item');
			if (!tabTitleItems) {
				return;
			}

			var currentTab = window.document.querySelector('#' + window.location.hash.substring(1));

			// Trigger tab change.
			var tabNumber = currentTab.querySelector('a').getAttribute('data-tab');
			var tabWrap = currentTab.closest('.bt-tabs-wrap');
			window.BBTabs.setActiveTab(tabWrap, tabNumber);

			if((window.BBTabs.isMobileSize() && tabWrap.classList.contains('bt-tabs-mobile-layout-accordion')) || (window.BBTabs.isTabletSize() && tabWrap.classList.contains('bt-tabs-tablet-layout-accordion'))) {
				tabWrap.querySelector('.bt-tabs-content-wrap > .bt-tabs-accordion-title.bt-tabs-accordion-title-' + tabNumber)
					.scrollIntoView({behavior: "smooth"});
			}
		},
		isMobileSize: function() {
			return window.innerWidth <= 767;
		},
		isTabletSize: function() {
			return window.innerWidth > 767 && window.innerWidth <= 1024;
		},
		setActiveTab: function( wrapper, tabNumber, moveFocus = true ) {

			const prevActiveAnchor = wrapper.querySelector(':scope > .bt-tabs-title-list > li.bt-tab-title-active a');
			const prevActiveListItem= wrapper.querySelector(':scope > .bt-tabs-title-list > li.bt-tab-title-active');
			prevActiveListItem.classList.replace('bt-tab-title-active', 'bt-tab-title-inactive')
			prevActiveAnchor.setAttribute('tabindex', '-1');
			prevActiveAnchor.setAttribute('aria-selected', 'false');

			wrapper.className = wrapper.className.replace(/\bbt-active-tab-\S+/g, 'bt-active-tab-' + tabNumber);
			const newActiveAnchor = wrapper.querySelector(':scope > .bt-tabs-title-list > li.bt-title-item-' + tabNumber + ' a');
			const newActiveListItem = wrapper.querySelector(':scope > .bt-tabs-title-list > li.bt-title-item-' + tabNumber);
			newActiveListItem.classList.replace('bt-tab-title-inactive', 'bt-tab-title-active');
			newActiveAnchor.setAttribute('tabindex', '0');
			newActiveAnchor.setAttribute('aria-selected', 'true');

			// Hide all tab panels.
			wrapper.querySelectorAll(':scope > .bt-tabs-content-wrap > .bt-tab-inner-content').forEach((subElem) => {
				subElem.style.display = 'none';
			});

			// Show selected tab panel.
			const newTabContent = wrapper.querySelector(':scope > .bt-tabs-content-wrap > .bt-inner-tab-' + tabNumber);
			newTabContent.style.display = 'block';

			if ( moveFocus ) {
				newActiveAnchor.focus();
			}

			window.BBTabs.setAriaAttributesForTabs(wrapper, tabNumber);

			var resizeEvent = new Event('resize');
			window.dispatchEvent(resizeEvent);
			var tabEvent = new Event('base-tabs-open');
			window.dispatchEvent(tabEvent);
		},
		setAriaAttributesForTabs: function( wrapper, tabNumber ) {
			wrapper.querySelectorAll(':scope > .bt-tabs-content-wrap > .bt-tab-inner-content:not(.bt-inner-tab-' + tabNumber + ')')
				.forEach((subElem) => subElem.setAttribute('aria-hidden', 'true'));
			wrapper.querySelector(':scope > .bt-tabs-content-wrap > .bt-inner-tab-' + tabNumber )
				.setAttribute( 'aria-hidden', 'false');
			// Accordion tabs
			wrapper.querySelectorAll(':scope > .bt-tabs-content-wrap > .bt-tabs-accordion-title:not(.bt-tabs-accordion-title-' + tabNumber + ')')
				.forEach((tab) => {
					tab.classList.replace('bt-tab-title-active', 'bt-tab-title-inactive');
					tab.setAttribute('tabindex', '-1');
					tab.setAttribute('aria-selected', 'false');
				});
			const activeAccordionTab = wrapper.querySelector(':scope >.bt-tabs-content-wrap > .bt-tabs-accordion-title.bt-tabs-accordion-title-' + tabNumber);
			if( activeAccordionTab ) {
				activeAccordionTab.classList.replace('bt-tab-title-inactive', 'bt-tab-title-active');
				activeAccordionTab.setAttribute('tabindex', '0');
				activeAccordionTab.setAttribute('aria-selected', 'true');
			}
		},

		init: function() {
			window.BBTabs.setupTabs()
			window.addEventListener( 'hashchange', window.BBTabs.setActiveWithHash, false );
		}
	}
	if ( 'loading' === document.readyState ) {
		// The DOM has not yet been loaded.
		document.addEventListener( 'DOMContentLoaded', window.BBTabs.init );
	} else {
		// The DOM has already been loaded.
		window.BBTabs.init();
	}
})();