
/**
 * BLOCK: Base Pane
 *
 * Registering a basic block with Gutenberg.
 */

import {
	RichText,
	InnerBlocks,
	useBlockProps
} from '@wordpress/block-editor';

/**
 * Import Icons
 */
import { accordionBlockIcon } from '@base/icons';
import { IconSpanTag } from '@base/components';

/**
 * Import edit
 */
import edit from './edit';
import metadata from './block.json';

/**
 * Import deprecated.
 */
import deprecated from './deprecated';


/**
 * Internal block libraries
 */
import { registerBlockType } from '@wordpress/blocks';
import { __ } from '@wordpress/i18n';

/**
 * Register: a Gutenberg Block.
 *
 * @link https://wordpress.org/gutenberg/handbook/block-api/
 * @param  {string}   name     Block name.
 * @param  {Object}   settings Block settings.
 * @return {?WPBlock}          The block, if it has been successfully
 *                             registered; otherwise `undefined`.
 */
registerBlockType( 'base/pane', {
	...metadata,
	title: __( 'Pane', 'gutenam-blocks' ),
	icon: accordionBlockIcon,
	getEditWrapperProps( attributes ) {
		return { 'data-pane': attributes.id };
	},
	edit,
	save( { attributes } ) {
		const { id, uniqueID, title, icon, iconSide, hideLabel, titleTag, ariaLabel } = attributes;
		const HtmlTagOut = ( ! titleTag ? 'div' : titleTag );

		const blockProps = useBlockProps.save( {
			className: `bt-accordion-pane bt-accordion-pane-${ id } bt-pane${ uniqueID }`
		} );

		return (
			<div {...blockProps}>
				<HtmlTagOut className={ 'bt-accordion-header-wrap' } >
					<button className={ `bt-blocks-accordion-header bt-acccordion-button-label-${ ( hideLabel ? 'hide' : 'show' ) }` } aria-label={ ariaLabel ? ariaLabel : undefined }>
						<span className="bt-blocks-accordion-title-wrap">
							{ icon && 'left' === iconSide && (
								<IconSpanTag
									extraClass={ `bt-btn-side-${ iconSide }` }
									name={ icon }
								/>
							) }
							<RichText.Content
								className={ 'bt-blocks-accordion-title' }
								tagName={ 'span' }
								value={ title }
							/>
							{ icon && 'right' === iconSide && (
								<IconSpanTag
									extraClass={ `bt-btn-side-${ iconSide }` }
									name={ icon }
								/>
							) }
						</span>
						<span className="bt-blocks-accordion-icon-trigger"></span>
					</button>
				</HtmlTagOut>
				<div className={ 'bt-accordion-panel' } >
					<div className={ 'bt-accordion-panel-inner' } >
						<InnerBlocks.Content />
					</div>
				</div>
			</div>
		);
	},
	deprecated,
	example: {}
} );
