/**
 * BLOCK: Base Testimonial
 */

/**
 * Import Icons
 */
import { IconRender } from '@base/components';

import attributes from './attributes';

/**
 * Internal block libraries
 */
import {
	RichText,
	InnerBlocks,
} from '@wordpress/block-editor';

/**
 * Register: a Gutenberg Block.
 *
 * @link https://wordpress.org/gutenberg/handbook/block-api/
 * @param  {string}   name     Block name.
 * @param  {Object}   settings Block settings.
 * @return {?WPBlock}          The block, if it has been successfully
 *                             registered; otherwise `undefined`.
 */
 export default [
	{
		attributes,
		save: ( { attributes } ) => {
			const { id, uniqueID, title, icon, iconSide, hideLabel, titleTag, ariaLabel } = attributes;
			const HtmlTagOut = ( ! titleTag ? 'div' : titleTag );

			return (
				<div className={ `bt-accordion-pane bt-accordion-pane-${ id } bt-pane${ uniqueID }` }>
					<HtmlTagOut className={ 'bt-accordion-header-wrap' } >
						<button className={ `bt-blocks-accordion-header bt-acccordion-button-label-${ ( hideLabel ? 'hide' : 'show' ) }` } aria-label={ ariaLabel ? ariaLabel : undefined }>
						<span className="bt-blocks-accordion-title-wrap">
							{ icon && 'left' === iconSide && (
								<IconRender className={ `bt-btn-svg-icon bt-btn-svg-icon-${ icon } bt-btn-side-${ iconSide }` } name={ icon } />
							) }
							<RichText.Content
								className={ 'bt-blocks-accordion-title' }
								tagName={ 'span' }
								value={ title }
							/>
							{ icon && 'right' === iconSide && (
								<IconRender className={ `bt-btn-svg-icon bt-btn-svg-icon-${ icon } bt-btn-side-${ iconSide }` } name={ icon } />
							) }
						</span>
							<span className="bt-blocks-accordion-icon-trigger"></span>
						</button>
					</HtmlTagOut>
					<div className={ 'bt-accordion-panel' } >
						<div className={ 'bt-accordion-panel-inner' } >
							<InnerBlocks.Content />
						</div>
					</div>
				</div>
			);
		},
	},
	{
		attributes,
		save: ( { attributes } ) => {
			const { id, uniqueID, title, icon, iconSide, hideLabel, titleTag } = attributes;
			const HtmlTagOut = ( ! titleTag ? 'div' : titleTag );
			return (
				<div className={ `bt-accordion-pane bt-accordion-pane-${ id } bt-pane${ uniqueID }` }>
					<HtmlTagOut className={ 'bt-accordion-header-wrap' } >
						<button className={ `bt-blocks-accordion-header bt-acccordion-button-label-${ ( hideLabel ? 'hide' : 'show' ) }` }>
							<div className="bt-blocks-accordion-title-wrap">
								{ icon && 'left' === iconSide && (
									<IconRender className={ `bt-btn-svg-icon bt-btn-svg-icon-${ icon } bt-btn-side-${ iconSide }` } name={ icon } />
								) }
								<RichText.Content
									className={ 'bt-blocks-accordion-title' }
									tagName={ 'span' }
									value={ title }
								/>
								{ icon && 'right' === iconSide && (
									<IconRender className={ `bt-btn-svg-icon bt-btn-svg-icon-${ icon } bt-btn-side-${ iconSide }` } name={ icon } />
								) }
							</div>
							<div className="bt-blocks-accordion-icon-trigger"></div>
						</button>
					</HtmlTagOut>
					<div className={ 'bt-accordion-panel' } >
						<div className={ 'bt-accordion-panel-inner' } >
							<InnerBlocks.Content />
						</div>
					</div>
				</div>
			);
		}
	}
];
