/**
 * WordPress dependencies
 */
import { __ } from '@wordpress/i18n';
import { Placeholder, Button, TextControl, ButtonGroup, TextareaControl } from '@wordpress/components';
import { BaseRadioButtons } from '@base/components';
import { useState } from '@wordpress/element';
import {
	formBlockIcon,
    formTemplateContactIcon,
    formTemplateContactAdvancedIcon,
    formTemplateSubscribeIcon,
    formTemplateSubscribeAdvancedIcon,
	formTemplateContactInFieldIcon,
    formTemplateContactDarkIcon,
    formTemplateContactUnderlineIcon,
	formTemplateContactAdvancedDarkIcon,
    formTemplateContactAdvancedUnderlineIcon,
    formTemplateContactAdvancedInFieldIcon,
	formTemplateSubscribeDarkIcon,
    formTemplateSubscribeUnderlineIcon,
    formTemplateSubscribeInFieldIcon,
    formTemplateSubscribeAdvancedDarkIcon,
    formTemplateSubscribeAdvancedUnderlineIcon,
    formTemplateSubscribeAdvancedInFieldIcon,
} from '@base/icons';
import { applyFilters } from '@wordpress/hooks';
import { map } from 'lodash';

export default function FormTitle( {
		setTitle,
		isAdding,
		existingTitle,
		onAdd,
	} ) {
	const [ tmpTitle, setTmpTitle ] = useState( existingTitle );
	const [ initialDescription, setTmpDescription ] = useState( '' );
	const [ wizardStep, setWizardStep ] = useState( 'start' );
	const [ template, setTemplate ] = useState( '' );
	const [ style, setStyle ] = useState( 'basic' );
	const [ isSaving, setIsSaving ] = useState( false );

	const formSteps = [
		{ key: 'start', name: __( 'Layout', 'gutenam-blocks' ) },
		{ key: 'style', name: __( 'Style', 'gutenam-blocks' ) },
		{ key: 'title', name: __( 'Title', 'gutenam-blocks' ) },
	];
	const startLayoutOptions = [
		{ key: 'skip', name: __( 'Skip (blank)', 'gutenam-blocks' ), icon: '', isDisabled: false},
		{ key: 'contact', name: __( 'Contact', 'gutenam-blocks' ), icon: formTemplateContactIcon, isDisabled: false },
		{ key: 'contactAdvanced', name: __( 'Contact With Options', 'gutenam-blocks' ), icon: formTemplateContactAdvancedIcon, isDisabled: false },
		{ key: 'subscribe', name: __( 'Subscribe', 'gutenam-blocks' ), icon: formTemplateSubscribeIcon, isDisabled: false },
		{ key: 'subscribeAdvanced', name: __( 'Subscribe With Name', 'gutenam-blocks' ), icon: formTemplateSubscribeAdvancedIcon, isDisabled: false },
	];
	let styleIcons = {
		'skip': formTemplateContactIcon,
		'dark': formTemplateContactDarkIcon,
		'infield': formTemplateContactInFieldIcon,
		'underline': formTemplateContactUnderlineIcon,
	}
	if ( 'subscribe' === template ) {
		styleIcons = {
			'skip': formTemplateSubscribeIcon,
			'dark': formTemplateSubscribeDarkIcon,
			'infield': formTemplateSubscribeInFieldIcon,
			'underline': formTemplateSubscribeUnderlineIcon,
		}
	} else if ( 'contactAdvanced' === template ) {
		styleIcons = {
			'skip': formTemplateContactAdvancedIcon,
			'dark': formTemplateContactAdvancedDarkIcon,
			'infield': formTemplateContactAdvancedInFieldIcon,
			'underline': formTemplateContactAdvancedUnderlineIcon,
		}
	} else if ( 'subscribeAdvanced' === template ) {
		styleIcons = {
			'skip': formTemplateSubscribeAdvancedIcon,
			'dark': formTemplateSubscribeAdvancedDarkIcon,
			'infield': formTemplateSubscribeAdvancedInFieldIcon,
			'underline': formTemplateSubscribeAdvancedUnderlineIcon,
		}
	}
	const startStyleOptions = [
		{ key: 'skip', name: __( 'Basic' ), icon: styleIcons['skip'], isDisabled: false},
		{ key: 'dark', name: __( 'Dark', 'gutenam-blocks' ), icon: styleIcons['dark'], isDisabled: false },
		{ key: 'infield', name: __( 'Infield', 'gutenam-blocks' ), icon: styleIcons['infield'], isDisabled: false },
		{ key: 'underline', name: __( 'Underline', 'gutenam-blocks' ), icon: styleIcons['underline'], isDisabled: false },
	];
	const formTemplates = applyFilters( 'base.formTemplates', startLayoutOptions );
	const formStyles = applyFilters( 'base.formStyles', startStyleOptions );
	return (
		<Placeholder
			className="bb-select-or-create-placeholder bb-adv-form-select"
			icon={formBlockIcon}
			label={__( 'Base Form', 'gutenam-blocks' )}
		>
			<div className='bb-form-wizard-pagination'>
				{ map( formSteps, ( { name, key }, index ) => (
					<Button
						key={ key }
						className="bb-form-pagination-btn"
						isSmall
						onClick={ () => {
							if ( key === 'style' && ( template === 'skip' || template === '' ) ) {
								setWizardStep( 'start' );
							} else {
								setWizardStep( key );
							}
						} }
						icon={ <span className="bb-form-pagination-icon">{index + 1 }</span> }
						aria-label={ sprintf(
							/* translators: 1: current page number 2: total number of pages */
							__( 'Page %1$d of %2$d', 'gutenam-blocks' ),
							index + 1,
							formSteps.length
						) }
						text={ name }
						isPressed={ wizardStep == key }
					/>
				) ) }
			</div>
			<div className="bb-select-or-create-placeholder__actions">
				{ wizardStep === 'start' && (
					<div className="bt-select-starter-style-forms">
						<div className="bt-select-starter-style-forms-title">
							{ __( 'Select Initial Layout', 'gutenam-blocks' ) }
						</div>
						<ButtonGroup className="bt-init-forms-btn-group" aria-label={ __( 'Initial Layout', 'gutenam-blocks' ) }>
							{ map( formTemplates, ( { name, key, icon, isDisabled } ) => (
								<Button
									key={ key }
									className="bt-inital-form-style-btn"
									isSmall
									onClick={ () => {
										setTemplate( key );
										if ( tmpTitle === '' ) {
											( 'skip' === key ? setTmpTitle( __( 'Blank Form', 'gutenam-blocks' ) ) : setTmpTitle( name + __( ' Form', 'gutenam-blocks' ) ) )
										}
										if ( 'skip' === key ) {
											setWizardStep( 'title' );
										} else {
											setWizardStep( 'style' );
										}
									} }
									isPressed={ template == key }
									label={name}
									isDisabled={ isDisabled }
								>
									{ name }
									{ icon }
									{ key !== 'skip' && (
										<span className='template-select'>{ __( 'Select', 'gutenam-blocks' ) }</span>
									) }
								</Button>
							) ) }
						</ButtonGroup>
					</div>
				) }
				{ wizardStep === 'style' && (
					<>
						<div className="bt-select-starter-style-forms bt-select-starter-styles-only">
							<div className="bt-select-starter-style-forms-title">
								{ __( 'Select Initial Style', 'gutenam-blocks' ) }
							</div>
							<ButtonGroup className="bt-init-forms-btn-group style-only" aria-label={ __( 'Initial Style', 'gutenam-blocks' ) }>
								{ map( formStyles, ( { name, key, icon, isDisabled } ) => (
									<Button
										key={ key }
										className="bt-inital-form-style-btn"
										isSmall
										onClick={ () => {
											setStyle( key );
											setWizardStep( 'title' );
										} }
										isPressed={ style == key }
										isDisabled={ isDisabled }
										label={name}
									>
										{ name }
										{ icon }
										<span className='template-select'>{ __( 'Select', 'gutenam-blocks' ) }</span>
									</Button>
								) ) }
							</ButtonGroup>
						</div>
					</>
				)}
				{ wizardStep === 'title' && (
					<>
						<TextControl
							className={ `bb-form-block-title${ ! tmpTitle ? ' base-input-required-warning' : '' }` }
							label={__( 'Give your form a title (required)', 'gutenam-blocks' )}
							placeholder={__( 'Contact Us', 'gutenam-blocks' )}
							help={ __( 'This is used for your reference only.', 'gutenam-blocks' )}
							value={tmpTitle}
							onChange={setTmpTitle}
							autoFocus
						/>
						<TextareaControl
							label={__( 'Form Description', 'gutenam-blocks' )}
							placeholder={__( 'Optionally add an description about your form', 'gutenam-blocks' )}
							help={ __( 'This is used for your reference only.', 'gutenam-blocks' )}
							value={initialDescription}
							onChange={setTmpDescription}
						/>
						<Button
							variant="primary"
							onClick={ () => { setIsSaving( true ); onAdd( tmpTitle, template, style, initialDescription ); } }
							isBusy={ isAdding }
							disabled={tmpTitle === '' || isSaving}
						>
							{__( 'Create', 'gutenam-blocks' )}
						</Button>
					</>
				)}
			</div>
		</Placeholder>
	);
}
