import { __ } from '@wordpress/i18n';
import {
	BasePanelBody,
	PopColorControl,
	TypographyControls,
	ColorGroup,
	ResponsiveBorderControl,
	ResponsiveMeasurementControls,
	ResponsiveMeasureRangeControl,
} from '@base/components';

export default function MessageStyling( { setMetaAttribute, useFormMeta } ) {

	const [ messageBorderRadius ] = useFormMeta( '_bst_form_messageBorderRadius' );
	const [ tabletMessageBorderRadius ] = useFormMeta( '_bst_form_tabletMessageBorderRadius' );
	const [ mobileMessageBorderRadius ] = useFormMeta( '_bst_form_mobileMessageBorderRadius' );
	const [ messageBorderRadiusUnit ] = useFormMeta( '_bst_form_messageBorderRadiusUnit' );

	const [ messagePadding ] = useFormMeta( '_bst_form_messagePadding' );
	const [ tabletMessagePadding ] = useFormMeta( '_bst_form_tabletMessagePadding' );
	const [ mobileMessagePadding ] = useFormMeta( '_bst_form_mobileMessagePadding' );
	const [ messagePaddingUnit ] = useFormMeta( '_bst_form_messagePaddingUnit' );

	const [ messageMargin ] = useFormMeta( '_bst_form_messageMargin' );
	const [ tabletMessageMargin ] = useFormMeta( '_bst_form_tabletMessageMargin' );
	const [ mobileMessageMargin ] = useFormMeta( '_bst_form_mobileMessageMargin' );
	const [ messageMarginUnit ] = useFormMeta( '_bst_form_messageMarginUnit' );

	const [ messageColor ] = useFormMeta( '_bst_form_messageColor' );
	const [ messageBackground ] = useFormMeta( '_bst_form_messageBackground' );
	const [ messageColorError ] = useFormMeta( '_bst_form_messageColorError' );
	const [ messageBackgroundError ] = useFormMeta( '_bst_form_messageBackgroundError' );

	const [ messageBorderSuccess ] = useFormMeta( '_bst_form_messageBorderSuccess' );
	const [ tabletMessageBorderSuccess ] = useFormMeta( '_bst_form_tabletMessageBorderSuccess' );
	const [ mobileMessageBorderSuccess ] = useFormMeta( '_bst_form_mobileMessageBorderSuccess' );

	const [ messageBorderError ] = useFormMeta( '_bst_form_messageBorderError' );
	const [ tabletMessageBorderError ] = useFormMeta( '_bst_form_tabletMessageBorderError' );
	const [ mobileMessageBorderError ] = useFormMeta( '_bst_form_mobileMessageBorderError' );
	const [ messageFont ] = useFormMeta( '_bst_form_messageFont' );

	const saveMessageFont = ( value ) => {
		setMetaAttribute( [ { ...messageFont[0], ...value } ], 'messageFont' );
	};

	return (
		<>
			<ColorGroup label={ __( 'Success Message Colors', 'gutenam-blocks' ) }>
				<PopColorControl
					label={__( 'Text Color', 'gutenam-blocks' )}
					value={( messageColor ? messageColor : '' )}
					default={''}
					onChange={ ( value ) => {
						setMetaAttribute( value, 'messageColor' );
					}}
				/>
				<PopColorControl
					label={__( 'Background Color', 'gutenam-blocks' )}
					value={( messageBackground ? messageBackground : '' )}
					default={''}
					onChange={ ( value ) => {
						setMetaAttribute( value, 'messageBackground' );
					}}
				/>
			</ColorGroup>
			<ResponsiveBorderControl
				label={__( 'Border', 'gutenam-blocks' )}
				value={ [messageBorderSuccess] }
				tabletValue={ [tabletMessageBorderSuccess] }
				mobileValue={ [mobileMessageBorderSuccess] }
				onChange={( value ) => setMetaAttribute( value[0], 'messageBorderSuccess' ) }
				onChangeTablet={( value ) => setMetaAttribute( value[0], 'tabletMessageBorderSuccess' ) }
				onChangeMobile={( value ) => setMetaAttribute( value[0], 'mobileMessageBorderSuccess' ) }
			/>
			<ColorGroup label={ __( 'Error Message Colors', 'gutenam-blocks' ) }>
				<PopColorControl
					label={__( 'Error Message Color', 'gutenam-blocks' )}
					value={( messageColorError ? messageColorError : '' )}
					default={''}
					onChange={ ( value ) => {
						setMetaAttribute( value, 'messageColorError' );
					}}
				/>
				<PopColorControl
					label={__( 'Error Message Background', 'gutenam-blocks' )}
					value={( messageBackgroundError ? messageBackgroundError : '' )}
					default={''}
					onChange={ ( value ) => {
						setMetaAttribute( value, 'messageBackgroundError' );
					}}
				/>
			</ColorGroup>
			<ResponsiveBorderControl
				label={__( 'Error Border', 'gutenam-blocks' )}
				value={ [messageBorderError] }
				tabletValue={ [tabletMessageBorderError] }
				mobileValue={ [mobileMessageBorderError] }
				onChange={( value ) => setMetaAttribute( value[0], 'messageBorderError' )}
				onChangeTablet={( value ) => setMetaAttribute( value[0], 'tabletMessageBorderError')}
				onChangeMobile={( value ) => setMetaAttribute( value[0], 'mobileMessageBorderError' )}
			/>
			<TypographyControls
				fontSize={messageFont[0].size}
				onFontSize={( value ) => saveMessageFont( { size: value } )}
				fontSizeType={messageFont[0].sizeType}
				onFontSizeType={( value ) => saveMessageFont( { sizeType: value } )}
				lineHeight={messageFont[0].lineHeight}
				onLineHeight={( value ) => saveMessageFont( { lineHeight: value } )}
				lineHeightType={messageFont[0].lineType}
				onLineHeightType={( value ) => saveMessageFont( { lineType: value } )}
				textTransform={messageFont[0].textTransform}
				onTextTransform={( value ) => saveMessageFont( { textTransform: value } )}
			/>
			<ResponsiveMeasurementControls
				label={__( 'Border Radius', 'gutenam-blocks' )}
				value={messageBorderRadius}
				tabletValue={tabletMessageBorderRadius}
				mobileValue={mobileMessageBorderRadius}
				onChange={( value ) => setMetaAttribute( value.map(String), 'messageBorderRadius' )}
				onChangeTablet={( value ) => setMetaAttribute( value.map(String), 'tabletMessageBorderRadius' )}
				onChangeMobile={( value ) => setMetaAttribute( value.map(String), 'mobileMessageBorderRadius' )}
				unit={messageBorderRadiusUnit}
				units={[ 'px', 'em', 'rem', '%' ]}
				onUnit={( value ) => setMetaAttribute( value, 'messageBorderRadiusUnit' )}
				max={(messageBorderRadiusUnit === 'em' || messageBorderRadiusUnit === 'rem' ? 24 : 500)}
				step={(messageBorderRadiusUnit === 'em' || messageBorderRadiusUnit === 'rem' ? 0.1 : 1)}
				min={ 0 }
				isBorderRadius={ true }
				allowEmpty={true}
			/>
			<BasePanelBody
				title={__( 'Advanced Message Font Settings', 'gutenam-blocks' )}
				initialOpen={false}
				panelName={'bb-form-advanced-message-font-settings'}
			>
				<TypographyControls
					fontGroup={'body'}
					reLetterSpacing={messageFont[0].letterSpacing}
					onLetterSpacing={( value ) => saveMessageFont( { letterSpacing: value } )}
					letterSpacingType={messageFont[0].letterType}
					onLetterSpacingType={( value ) => saveMessageFont( { letterType: value } )}
					fontFamily={messageFont[0].family}
					onFontFamily={( value ) => saveMessageFont( { family: value } )}
					onFontChange={( select ) => {
						saveMessageFont( {
							family: select.value,
							google: select.google,
						} );
					}}
					onFontArrayChange={( values ) => saveMessageFont( values )}
					googleFont={messageFont[0].google}
					onGoogleFont={( value ) => saveMessageFont( { google: value } )}
					loadGoogleFont={messageFont[0].loadGoogle}
					onLoadGoogleFont={( value ) => saveMessageFont( { loadGoogle: value } )}
					fontVariant={messageFont[0].variant}
					onFontVariant={( value ) => saveMessageFont( { variant: value } )}
					fontWeight={messageFont[0].weight}
					onFontWeight={( value ) => saveMessageFont( { weight: value } )}
					fontStyle={messageFont[0].style}
					onFontStyle={( value ) => saveMessageFont( { style: value } )}
					fontSubset={messageFont[0].subset}
					onFontSubset={( value ) => saveMessageFont( { subset: value } )}
				/>
			</BasePanelBody>
			<ResponsiveMeasureRangeControl
				label={__( 'Padding', 'gutenam-blocks' )}
				value={ messagePadding }
				tabletValue={tabletMessagePadding}
				mobileValue={mobileMessagePadding}
				onChange={( value ) => {
					setMetaAttribute( value.map(String), 'messagePadding' );
				}}
				onChangeTablet={( value ) => {
					setMetaAttribute( value.map(String), 'tabletMessagePadding' );
				}}
				onChangeMobile={( value ) => {
					setMetaAttribute( value.map(String), 'mobileMessagePadding' );
				}}
				min={ 0 }
				max={ ( messagePaddingUnit === 'em' || messagePaddingUnit === 'rem' ? 24 : 500 ) }
				step={ ( messagePaddingUnit === 'em' || messagePaddingUnit === 'rem' ? 0.1 : 1 ) }
				unit={ messagePaddingUnit }
				units={ [ 'px', 'em', 'rem', '%', 'vh', 'vw' ] }
				onUnit={( value ) => setMetaAttribute( value, 'messagePaddingUnit' )}
			/>
			<ResponsiveMeasureRangeControl
				label={__( 'Margin', 'gutenam-blocks' )}
				value={messageMargin}
				tabletValue={tabletMessageMargin}
				mobileValue={mobileMessageMargin}
				onChange={( value ) => {
					setMetaAttribute( value.map(String), 'messageMargin' );
				}}
				onChangeTablet={( value ) => {
					setMetaAttribute( value.map(String), 'tabletMessageMargin' );
				}}
				onChangeMobile={( value ) => {
					setMetaAttribute( value.map(String), 'mobileMessageMargin' );
				}}
				min={ ( messageMarginUnit === 'em' || messageMarginUnit === 'rem' ? -24 : -500 ) }
				max={ ( messageMarginUnit === 'em' || messageMarginUnit === 'rem' ? 24 : 500 ) }
				step={ ( messageMarginUnit === 'em' || messageMarginUnit === 'rem' ? 0.1 : 1 ) }
				unit={ messageMarginUnit }
				units={ [ 'px', 'em', 'rem', '%', 'vh', 'vw' ] }
				onUnit={ ( value ) => setMetaAttribute( value, 'messageMarginUnit' ) }
			/>
		</>
	);

}
