/**
 * Webhook Controls
 *
 */

/**
 * Imports
 */
import { getFormFields } from '../../';

/**
 * Internal block libraries
 */
import { __ } from '@wordpress/i18n';
import {
	useMemo,
} from '@wordpress/element';
import {
	TextControl,
} from '@wordpress/components';
import { BasePanelBody } from '@base/components';

/**
 * Build the Measure controls
 * @returns {object} Measure settings.
 */
function WebhookOptions( { formInnerBlocks, parentClientId, settings, save } ) {

	const fields = useMemo( () => getFormFields( formInnerBlocks ), [ parentClientId ] );
	const SLUG_REGEX = /[\s#]/g;

	const saveMap = ( value, uniqueID ) => {
		let updatedMap = { ...settings.map }
		updatedMap[uniqueID] = value;
		save( { map: updatedMap } );
	};

	return (
		<BasePanelBody
			title={__( 'Webhook Settings', 'gutenam-blocks' )}
			initialOpen={false}
			panelName={'bb-webhook-settings'}
		>
			<TextControl
				label={__( 'Webhook URL', 'gutenam-blocks' )}
				help={__( 'Enter the URL that will receive the form submitted data.', 'gutenam-blocks' )}
				value={( undefined !== settings.url ? settings.url : '' )}
				onChange={( value ) => save( { url: value } )}
			/>

			<>
				<h2 className="bt-heading-size-title">{__( 'Map Fields', 'gutenam-blocks' )}</h2>
				{fields && (
					fields.map( ( item, index ) => {
						return (
							<div key={index} className="bb-field-map-item">
								<div className="bb-field-map-item-form">
									<p className="bb-field-map-item-label">{__( 'Form Field', 'gutenam-blocks' )}</p>
									<p className="bb-field-map-item-name">{item.label}</p>
								</div>
								<TextControl
									label={__( 'Webhook Field Name', 'gutenam-blocks' )}
									value={( undefined !== settings.map && undefined !== settings.map[ item.uniqueID ] && settings.map[ item.uniqueID ] ? settings.map[ item.uniqueID ] : '' )}
									onChange={( nextValue ) => {
										nextValue = nextValue.replace( SLUG_REGEX, '-' );
										saveMap( nextValue, item.uniqueID );
									}}
								/>
							</div>
						);
					} )
				)}
			</>
		</BasePanelBody>
	);
}

export default ( WebhookOptions );
