/**
 * BLOCK: Base Block Template
 */

/**
 * Import Css
 */
import './editor.scss';

/**
 * Internal block libraries
 */
import { __ } from '@wordpress/i18n';
import { useState, useCallback, useEffect } from '@wordpress/element';
import { useSelect, useDispatch } from '@wordpress/data';
import { createBlock } from '@wordpress/blocks';
import { size, get, isEqual } from 'lodash';
import { addQueryArgs } from '@wordpress/url';
import {
	useEntityBlockEditor,
	useEntityProp,
} from '@wordpress/core-data';
import { store as editorStore } from '@wordpress/block-editor';
import { formBlockIcon } from '@base/icons';
import {
	BasePanelBody,
	InspectorControlTabs,
	URLInputControl,
	ResponsiveMeasureRangeControl,
	SpacingVisualizer,
	BackgroundTypeControl,
	PopColorControl,
	ResponsiveRangeControls,
	GradientControl
} from '@base/components';
import {
	getPreviewSize,
	BaseColorOutput,
	getSpacingOptionOutput,
	mouseOverVisualizer
} from '@base/helpers';

import {
	useBlockProps,
	RichText,
	BlockAlignmentControl,
	InnerBlocks,
	InspectorControls,
	BlockControls,
	useInnerBlocksProps,
	InspectorAdvancedControls,
	BlockVerticalAlignmentControl,
	JustifyContentControl,
} from '@wordpress/block-editor';
import {
	TextControl,
	SelectControl,
	ToggleControl,
	ToolbarGroup,
	ToolbarButton,
	Button,
	Placeholder,
	TextareaControl,
} from '@wordpress/components';

import {
	FieldStyles,
	SubmitActionOptions,
	LabelOptions,
	RadioLabelOptions,
	HelpTextOptions,
	MailerLiteOptions,
	FluentCrmOptions,
	SendinBlueOptions,
	MailchimpOptions,
	ConvertKitOptions,
	ActiveCampaignOptions,
	FormTitle,
	WebhookOptions,
	AutoEmailOptions,
	DbEntryOptions,
	BackendStyles,
	MessageOptions,
	MessageStyling,
	getFormFields,
	FieldBlockAppender,
	SelectForm,
} from './components';

/**
 * Internal dependencies
 */
import classnames from 'classnames';
import { useEntityPublish } from './hooks';
const ALLOWED_BLOCKS = [ 'core/paragraph', 'base/advancedheading', 'base/spacer', 'base/rowlayout', 'base/column', 'base/advanced-form-text', 'base/advanced-form-textarea', 'base/advanced-form-select', 'base/advanced-form-submit', 'base/advanced-form-radio', 'base/advanced-form-file', 'base/advanced-form-time', 'base/advanced-form-date', 'base/advanced-form-telephone', 'base/advanced-form-checkbox', 'base/advanced-form-email', 'base/advanced-form-accept', 'base/advanced-form-number', 'base/advanced-form-hidden', 'base/advanced-form-captcha' ];

export function EditInner( props ) {

	const {
		attributes,
		setAttributes,
		className,
		clientId,
		direct,
		id,
		isSelected,
	} = props;
	const {
		uniqueID
	} = attributes;

	const { previewDevice } = useSelect(
		( select ) => {
			return {
				previewDevice: select( 'baseblocks/data' ).getPreviewDeviceType(),
			};
		},
		[ clientId ],
	);

	const [ activeTab, setActiveTab ] = useState( 'general' );

	const paddingMouseOver = mouseOverVisualizer();
	const marginMouseOver = mouseOverVisualizer();

	const [ fields ] = useFormMeta( '_bst_form_fields' )
	const [ email ] = useFormMeta( '_bst_form_email' );
	const [ actions ] = useFormMeta( '_bst_form_actions' );
	const [ mailerlite ] = useFormMeta( '_bst_form_mailerlite' );
	const [ fluentcrm ] = useFormMeta( '_bst_form_fluentcrm' );
	const [ sendinblue ] = useFormMeta( '_bst_form_sendinblue' );
	const [ mailchimp ] = useFormMeta( '_bst_form_mailchimp' );
	const [ convertkit ] = useFormMeta( '_bst_form_convertkit' );
	const [ activecampaign ] = useFormMeta( '_bst_form_activecampaign' );

	const [ redirect ] = useFormMeta( '_bst_form_redirect' );
	const [ description ] = useFormMeta( '_bst_form_description' );

	const [ webhook ] = useFormMeta( '_bst_form_webhook' );
	const [ autoEmail ] = useFormMeta( '_bst_form_autoEmail' );
	const [ entry ] = useFormMeta( '_bst_form_entry' );
	const [ messages ] = useFormMeta( '_bst_form_messages' );

	const [ labelFont ] = useFormMeta( '_bst_form_labelFont' );
	const [ inputFont ] = useFormMeta( '_bst_form_inputFont' );

	const [ padding ] = useFormMeta( '_bst_form_padding' );
	const [ tabletPadding ] = useFormMeta( '_bst_form_tabletPadding' );
	const [ mobilePadding ] = useFormMeta( '_bst_form_mobilePadding' );
	const [ paddingUnit ] = useFormMeta( '_bst_form_paddingUnit' );

	const [ margin ] = useFormMeta( '_bst_form_margin' );
	const [ tabletMargin ] = useFormMeta( '_bst_form_tabletMargin' );
	const [ mobileMargin ] = useFormMeta( '_bst_form_mobileMargin' );
	const [ marginUnit ] = useFormMeta( '_bst_form_marginUnit' );

	const [ style ] = useFormMeta( '_bst_form_style' );
	const [ background ] = useFormMeta( '_bst_form_background' );
	const [ helpFont ] = useFormMeta( '_bst_form_helpFont' );
	const [ radioLabelFont ] = useFormMeta( '_bst_form_radioLabelFont' );
	const [ maxWidth ] = useFormMeta( '_bst_form_maxWidth' );
	const [ maxWidthUnit ] = useFormMeta( '_bst_form_maxWidthUnit');
	const [ submitHide ] = useFormMeta( '_bst_form_submitHide' );

	const [ meta, setMeta ] = useFormProp( 'meta' );

	const setMetaAttribute = ( value, key ) => {
		setMeta( { ...meta, ['_bst_form_' + key]: value } );
	};
	const saveBackgroundStyle = ( value ) => {
		setMetaAttribute( { ...background, ...value }, 'background' );
	};
	const saveStyle = ( value ) => {
		setMetaAttribute( { ...style, ...value }, 'style');
	}
	const saveInputFont = ( value ) => {
		setMetaAttribute( { ...inputFont, ...value }, 'inputFont');
	};
	const saveLabelFont = ( value ) => {
		setMetaAttribute( { ...labelFont, ...value }, 'labelFont' );
	};
	const previewMarginTop = getPreviewSize( previewDevice, ( undefined !== margin ? margin[ 0 ] : '' ), ( undefined !== tabletMargin ? tabletMargin[ 0 ] : '' ), ( undefined !== mobileMargin ? mobileMargin[ 0 ] : '' ) );
	const previewMarginRight = getPreviewSize( previewDevice, ( undefined !== margin ? margin[ 1 ] : '' ), ( undefined !== tabletMargin ? tabletMargin[ 1 ] : '' ), ( undefined !== mobileMargin ? mobileMargin[ 1 ] : '' ) );
	const previewMarginBottom = getPreviewSize( previewDevice, ( undefined !== margin ? margin[ 2 ] : '' ), ( undefined !== tabletMargin ? tabletMargin[ 2 ] : '' ), ( undefined !== mobileMargin ? mobileMargin[ 2 ] : '' ) );
	const previewMarginLeft = getPreviewSize( previewDevice, ( undefined !== margin ? margin[ 3 ] : '' ), ( undefined !== tabletMargin ? tabletMargin[ 3 ] : '' ), ( undefined !== mobileMargin ? mobileMargin[ 3 ] : '' ) );

	const previewPaddingTop = getPreviewSize( previewDevice, ( undefined !== padding ? padding[ 0 ] : '' ), ( undefined !== tabletPadding ? tabletPadding[ 0 ] : '' ), ( undefined !== mobilePadding ? mobilePadding[ 0 ] : '' ) );
	const previewPaddingRight = getPreviewSize( previewDevice, ( undefined !== padding ? padding[ 1 ] : '' ), ( undefined !== tabletPadding ? tabletPadding[ 1 ] : '' ), ( undefined !== mobilePadding ? mobilePadding[ 1 ] : '' ) );
	const previewPaddingBottom = getPreviewSize( previewDevice, ( undefined !== padding ? padding[ 2 ] : '' ), ( undefined !== tabletPadding ? tabletPadding[ 2 ] : '' ), ( undefined !== mobilePadding ? mobilePadding[ 2 ] : '' ) );
	const previewPaddingLeft = getPreviewSize( previewDevice, ( undefined !== padding ? padding[ 3 ] : '' ), ( undefined !== tabletPadding ? tabletPadding[ 3 ] : '' ), ( undefined !== mobilePadding ? mobilePadding[ 3 ] : '' ) );

	const previewMaxWidth = getPreviewSize( previewDevice, ( undefined !== maxWidth?.[0] ? maxWidth[0] : '' ), ( undefined !== maxWidth?.[1] ? maxWidth[1] : '' ), ( undefined !== maxWidth?.[2] ? maxWidth[2] : '' ) );
	const backgroundType = ( undefined !== background?.backgroundType && '' !== background?.backgroundType ? background.backgroundType : 'normal' );
	let hasBackground = ( 'normal' === backgroundType && undefined !== background?.background && '' !== background?.background ? true : false );
	if ( ! hasBackground ) {
		hasBackground = ( 'gradient' === backgroundType && undefined !== background?.gradient && '' !== background?.gradient ? true : false );
	}
	const previewBackground = ( 'gradient' === backgroundType ? background?.gradient : background?.background );

	const formClasses = classnames( {
		'bb-advanced-form'          : true,
		[ `bb-advanced-form-${id}` ]: true,
		[ `bb-form${uniqueID}` ]: uniqueID,
		[ `bb-form-label-style-${style?.labelStyle}` ]: style?.labelStyle,
		[ `bb-form-basic-style` ]: ( undefined !== style?.basicStyles && false === style.basicStyles ? false : true ),
		[ `bb-form-hide-required-asterisk` ]: ( undefined !== style?.showRequired && false === style.showRequired ? true : false ),
		[ `bb-form-has-background` ]: hasBackground,
		[ `bb-form-is-dark` ]: undefined !== style?.isDark && true === style.isDark,
		[ `bb-form-input-size-${style?.size}` ]: style?.size,
	} );

	const [ title, setTitle ] = useFormProp( 'title' );

	const [ blocks, onInput, onChange ] = useEntityBlockEditor(
		'postType',
		'base_form',
		id,
	);
	const {
		insertBlocks,
	} = useDispatch( editorStore );
	let formInnerBlocks = get( blocks, [ 0, 'innerBlocks' ], [] );
	useEffect( () => {
		if ( Array.isArray( formInnerBlocks ) && formInnerBlocks.length ) {
			let currentFields = getFormFields( formInnerBlocks );
			if ( ! isEqual( fields, currentFields ) ) {
				setMetaAttribute( currentFields, 'fields' );
			}
		}
	}, [formInnerBlocks] );
	let newBlock = get( blocks, [ 0 ], {} );

	const [ isAdding, addNew ] = useEntityPublish( 'base_form', id );
	const onAdd = async( title, template, style, initialDescription ) => {
		try {
			const response = await addNew();
			let buttonAttributes = {
				text: 'Submit',
				widthType: 'full'
			};
			if ( 'subscribe' === template && 'infield' === style ) {
				buttonAttributes = {
					typography: [ {
						"size": [
							"",
							"",
							""
						],
						"sizeType": "px",
						"lineHeight": [
							"42",
							"",
							""
						],
						"lineType": "px",
						"letterSpacing": [
							"",
							"",
							""
						],
						"letterType": "px",
						"textTransform": "",
						"family": "",
						"google": "",
						"style": "",
						"weight": "",
						"variant": "",
						"subset": "",
						"loadGoogle": true
					}],
					text: 'Submit',
					widthType: 'full'
				};
			}
			if ( response.id ) {
				switch ( template ) {
					case 'contact':
						insertBlocks(
							[
								createBlock( 'base/rowlayout', { colLayout: 'equal', padding: ['0','0','0','0'] }, [
									createBlock( 'base/column', {}, [
										createBlock( 'base/advanced-form-text', { label: 'Name' } )
									] ),
									createBlock( 'base/column', {}, [
										createBlock( 'base/advanced-form-email', { label: 'Email', required: true } )
									] ) 
								] ),
								createBlock( 'base/advanced-form-textarea', { label: 'Message', required: true } ),
								createBlock( 'base/advanced-form-submit', { text: 'Submit' } )
							],
							0,
							clientId,
							false
						);
						break;
					case 'contactAdvanced':
						insertBlocks(
							[
								createBlock( 'base/rowlayout', { colLayout: 'equal', padding: ['0','0','0','0'] }, [
									createBlock( 'base/column', {}, [
										createBlock( 'base/advanced-form-text', { label: 'Name' } )
									] ),
									createBlock( 'base/column', {}, [
										createBlock( 'base/advanced-form-email', { label: 'Email', required: true } ),
									] ) 
								] ),
								createBlock( 'base/rowlayout', { colLayout: 'equal', padding: ['0','0','0','0'] }, [
									createBlock( 'base/column', {}, [
										createBlock( 'base/advanced-form-select', { label: 'Option 1' } )
									] ),
									createBlock( 'base/column', {}, [
										createBlock( 'base/advanced-form-select', { label: 'Option 2' } )
									] ) 
								] ),
								createBlock( 'base/advanced-form-textarea', { label: 'Message', required: true } ),
								createBlock( 'base/advanced-form-submit', { text: 'Submit' } ) 
							],
							0,
							clientId,
							false
						);
						break;
					case 'subscribeAdvanced':
						insertBlocks(
							[
								createBlock( 'base/rowlayout', { colLayout: 'equal', padding: ['0','0','0','0'] }, [
									createBlock( 'base/column', {}, [
										createBlock( 'base/advanced-form-text', { label: 'Name' } )
									] ),
									createBlock( 'base/column', {}, [
										createBlock( 'base/advanced-form-email', { label: 'Email', required: true } )
									] ) 
								] ),
								createBlock( 'base/advanced-form-submit', { text: 'Submit' } )
							],
							0,
							clientId,
							false
						);
						break;
					case 'subscribe':
						insertBlocks(
							[
								createBlock( 'base/rowlayout', { colLayout: 'left-golden', padding: ['0','0','0','0'] }, [
									createBlock( 'base/column', {}, [
										createBlock( 'base/advanced-form-email', { label: 'Email', required: true } )
									] ),
									createBlock( 'base/column', { verticalAlignment: 'bottom' }, [
										createBlock( 'base/advanced-form-submit', buttonAttributes ) 
									] ) 
								] ),
							],
							0,
							clientId,
							false
						);
						break;
					default:
						insertBlocks(
							[ 
								createBlock( 'core/paragraph', {} ),
								createBlock( 'base/advanced-form-submit', { text: 'Submit' } ),
							],
							0,
							clientId,
							false
						);
						break;
				}
				setTitle(title);
				let updatedMeta = meta;
				if ( base_blocks_params.pro === 'true' && updatedMeta?._bst_form_actions && ! updatedMeta._bst_form_actions.includes( 'entry' ) ) {
					updatedMeta._bst_form_actions.push('entry');
				}
				updatedMeta._bst_form_description = initialDescription;
				if ( style === 'dark' ) {
					updatedMeta._bst_form_style = { ...updatedMeta._bst_form_style, background: 'palette3', isDark: true, placeholderColor: 'palette6', borderActive: 'palette7' };
					updatedMeta._bst_form_inputFont = { ...updatedMeta._bst_form_inputFont, color: 'palette9' };
					updatedMeta._bst_form_labelFont = { ...updatedMeta._bst_form_labelFont, color: 'palette9' };
					updatedMeta._bst_form_background = { ...updatedMeta._bst_form_background, background: 'palette3' };
					const borderStyle = {
						top: ['palette6','',1],
						right: ['palette6','',1],
						bottom: ['palette6','',1],
						left: ['palette6','',1],
						unit: 'px',
					};
					updatedMeta._bst_form_fieldBorderStyle = borderStyle;
				} else if ( style === 'infield' ) {
					updatedMeta._bst_form_style = { ...updatedMeta._bst_form_style, labelStyle: 'infield' };
				} else if ( style === 'underline' ) {
					const borderStyle = {
						top: ['#B9B9C5','',0],
						right: ['#B9B9C5','',0],
						bottom: ['#B9B9C5','',2],
						left: ['#B9B9C5','',0],
						unit: 'px',
					}
					updatedMeta._bst_form_labelFont = { ...updatedMeta._bst_form_labelFont, color: '#909097' };
					updatedMeta._bst_form_style = { ...updatedMeta._bst_form_style, labelStyle: 'float', borderActive: 'palette1', boxShadow: [ true, '#000000', 0, 0, 0, 0, 0, false ], boxShadowActive: [ true, '#000000', 0, 0, 0, 0, 0, false ] };
					updatedMeta._bst_form_fieldBorderStyle = borderStyle;
					updatedMeta._bst_form_fieldBorderRadius = [0,0,0,0];
				}
				setMeta( { ...meta, updatedMeta } );
				await wp.data.dispatch( 'core' ).saveEditedEntityRecord( 'postType', 'base_form', id );
			}
		} catch ( error ) {
			console.error( error );
		}
	};
	const useFieldBlockAppender = () => {
		if ( isSelected ) {
			return null;
		}
		return (
			<FieldBlockAppender inline={ true } rootClientId={ clientId } />
		);
	};
	const useFieldBlockAppenderBase = () => {
		return (
			<FieldBlockAppender inline={ false } rootClientId={ clientId } />
		);
	};
	const innerBlocksProps = useInnerBlocksProps(
		{
			className: formClasses,
			style: {
				marginTop   : ( '' !== previewMarginTop ? getSpacingOptionOutput( previewMarginTop, marginUnit ) : undefined ),
				marginRight : ( '' !== previewMarginRight ? getSpacingOptionOutput( previewMarginRight, marginUnit ) : undefined ),
				marginBottom: ( '' !== previewMarginBottom ? getSpacingOptionOutput( previewMarginBottom, marginUnit ) : undefined ),
				marginLeft  : ( '' !== previewMarginLeft ? getSpacingOptionOutput( previewMarginLeft, marginUnit ) : undefined ),

				paddingTop   : ( '' !== previewPaddingTop ? getSpacingOptionOutput( previewPaddingTop, paddingUnit ) : undefined ),
				paddingRight : ( '' !== previewPaddingRight ? getSpacingOptionOutput( previewPaddingRight, paddingUnit ) : undefined ),
				paddingBottom: ( '' !== previewPaddingBottom ? getSpacingOptionOutput( previewPaddingBottom, paddingUnit ) : undefined ),
				paddingLeft  : ( '' !== previewPaddingLeft ? getSpacingOptionOutput( previewPaddingLeft, paddingUnit ) : undefined ),

				maxWidth: ( '' !== previewMaxWidth ? previewMaxWidth + maxWidthUnit : undefined ),
				background: ( '' !== previewBackground ? BaseColorOutput( previewBackground ) : undefined ),
			}
		},
		{
			allowedBlocks: ALLOWED_BLOCKS,
			value: ! direct ? formInnerBlocks : undefined,
			onInput: ! direct ? ( a, b ) => onInput( [ { ...newBlock, innerBlocks: a } ], b ) : undefined,
			onChange: ! direct ? ( a, b ) => onChange( [ { ...newBlock, innerBlocks: a } ], b ) : undefined,
			templateLock: false,
			renderAppender: formInnerBlocks.length === 0 ? useFieldBlockAppenderBase : useFieldBlockAppender
		}
	);
	if ( formInnerBlocks.length === 0 ) {
		return (
			<>
				<FormTitle
					onAdd={ onAdd }
					isAdding={ isAdding }
					existingTitle={ title }
				/>
				<div className='bb-form-hide-while-setting-up'>
					<div {...innerBlocksProps} />
				</div>
			</>
		);
	}
	if ( typeof pagenow !== 'undefined' && ( 'widgets' === pagenow || 'customize' === pagenow ) ) {
		const editPostLink = addQueryArgs( 'post.php', { 
			post: id, 
			action: 'edit' 
		} );
		return (
			<>
				<Placeholder
					className="bb-select-or-create-placeholder"
					label={__( 'Base Form', 'gutenam-blocks' )}
					icon={ formBlockIcon }
				>
					<p style={{ width: '100%', marginBottom:'10px'}}>{ __( 'Advanced forms can not be edited within the widgets screen.', 'gutenam-blocks' ) }</p>
					<Button href={ editPostLink } variant='primary' className='bb-form-edit-link'>
						{ __( 'Edit Form', 'gutenam-blocks' ) }
					</Button>
				</Placeholder>
				<InspectorControls>
					<BasePanelBody
							panelName={'bb-advanced-form-selected-switch'}
							title={ __( 'Selected Form', 'gutenam-blocks' ) }
						>
						<SelectForm
							postType="base_form"
							label={__( 'Selected Form', 'gutenam-blocks' )}
							hideLabelFromVision={ true }
							onChange={ ( nextId ) => {
								setAttributes( { id: parseInt( nextId ) } ) 
							} }
							value={ id }
						/>
					</BasePanelBody>
				</InspectorControls>
			</>
		);
	}
	return (
		<>
			<style>
				{ isSelected && (
					<>
					{ `.block-editor-block-popover__inbetween-container .block-editor-block-list__insertion-point.is-with-inserter { display: none }` };
					</>
				)}
			</style>
			<BlockControls>
				<ToolbarGroup group="add-block" className="bb-add-block">
					<FieldBlockAppender rootClientId={clientId} />
				</ToolbarGroup>
			</BlockControls>

			<InspectorControls>

				<InspectorControlTabs
					panelName={'advanced-form'}
					setActiveTab={( value ) => setActiveTab( value )}
					activeTab={activeTab}
				/>

				{( activeTab === 'general' ) &&

					<>
						{ ! direct && (
							<BasePanelBody
								panelName={'bb-advanced-form-selected-switch'}
								title={ __( 'Selected Form', 'gutenam-blocks' ) }
							>
								<SelectForm
									postType="base_form"
									label={__( 'Selected Form', 'gutenam-blocks' )}
									hideLabelFromVision={ true }
									onChange={ ( nextId ) => setAttributes( { id: parseInt( nextId ) } ) }
									value={ id }
								/>
								<TextareaControl
									label={__( 'Form Description', 'gutenam-blocks' )}
									placeholder={__( 'Optionally add an description about your form', 'gutenam-blocks' )}
									help={ __( 'This is used for your reference only.', 'gutenam-blocks' )}
									value={( undefined !== description ? description : '' )}
									onChange={value => setMetaAttribute( value, 'description' )}
								/>
							</BasePanelBody>
						) }
						{ direct && (
							<BasePanelBody
								panelName={'bb-advanced-form-selected-switch'}
								title={ __( 'Form', 'gutenam-blocks' ) }
							>
								<TextareaControl
									label={__( 'Form Description', 'gutenam-blocks' )}
									placeholder={__( 'Optionally add an description about your form', 'gutenam-blocks' )}
									help={ __( 'This is used for your reference only.', 'gutenam-blocks' )}
									value={( undefined !== description ? description : '' )}
									onChange={value => setMetaAttribute( value, 'description' )}
								/>
							</BasePanelBody>
						) }
						<BasePanelBody
							panelName={'bb-advanced-form-submit-actions'}
							title={__( 'Submit Actions', 'gutenam-blocks' )}
						>
							<SubmitActionOptions setAttributes={setMetaAttribute} selectedActions={actions}/>
							<ToggleControl
								label={__( 'Hide form after submit?', 'gutenam-blocks' )}
								checked={( undefined !== submitHide ? submitHide : false )}
								onChange={( value ) => {
									setMetaAttribute( value, 'submitHide' );
								} }
							/>

						</BasePanelBody>

						{size( actions ) > 0 && (
							<div className="bt-sidebar-settings-spacer"></div>
						)}

						{actions.includes( 'email' ) && (
							<BasePanelBody
								title={__( 'Email Settings', 'gutenam-blocks' )}
								initialOpen={false}
								panelName={'bb-form-email-settings'}
							>
								<TextControl
									label={__( 'Email To Address', 'gutenam-blocks' )}
									placeholder={__( 'name@example.com', 'gutenam-blocks' )}
									value={( undefined !== email.emailTo ? email.emailTo : '' )}
									onChange={( value ) => setMetaAttribute( { ...email, emailTo: value }, 'email' )}
									help={__( 'Seperate with comma for more then one email address.', 'gutenam-blocks' )}
								/>
								<TextControl
									label={__( 'Email Subject', 'gutenam-blocks' )}
									value={( undefined !== email.subject ? email.subject : '' )}
									onChange={( value ) => setMetaAttribute({ ...email, subject: value }, 'email' )}
								/>
								<TextControl
									label={__( 'From Email', 'gutenam-blocks' )}
									value={( undefined !== email.fromEmail ? email.fromEmail : '' )}
									onChange={( value ) => setMetaAttribute( { ...email, fromEmail: value },'email')}
								/>
								<TextControl
									label={__( 'From Name', 'gutenam-blocks' )}
									value={( undefined !== email.fromName ? email.fromName : '' )}
									onChange={( value ) => setMetaAttribute( { ...email, fromName: value }, 'email' )}
								/>
								<SelectControl
									label={__( 'Reply To', 'gutenam-blocks' )}
									value={email.replyTo}
									options={[
										{ value: 'email_field', label: __( 'Email Field', 'gutenam-blocks' ) },
										{ value: 'from_email', label: __( 'From Email', 'gutenam-blocks' ) },
									]}
									onChange={value => {
										setMetaAttribute( { ...email, replyTo: value }, 'email' );
									}}
								/>
								<TextControl
									label={__( 'Cc', 'gutenam-blocks' )}
									value={( undefined !== email.cc ? email.cc : '' )}
									onChange={( value ) => setMetaAttribute( { ...email, cc: value }, 'email' )}
								/>
								<TextControl
									label={__( 'Bcc', 'gutenam-blocks' )}
									value={( undefined !== email.bcc ? email.bcc : '' )}
									onChange={( value ) => setMetaAttribute( { ...email, bcc: value }, 'email' )}
								/>
								<ToggleControl
									label={__( 'Send as HTML email?', 'gutenam-blocks' )}
									help={__( 'If off plain text is used.', 'gutenam-blocks' )}
									checked={( undefined !== email.html ? email.html : true )}
									onChange={( value ) => setMetaAttribute( { ...email, html: value }, 'email' )}
								/>
							</BasePanelBody>
						)}

						{actions.includes( 'redirect' ) && (
							<BasePanelBody
								title={__( 'Redirect Settings', 'gutenam-blocks' )}
								initialOpen={false}
								panelName={'bb-form-redirect-settings'}
							>
								<URLInputControl
									label={__( 'Redirect to', 'gutenam-blocks' )}
									url={redirect}
									onChangeUrl={value => setMetaAttribute( value, 'redirect' )}
									additionalControls={false}
								/>
							</BasePanelBody>
						)}

						{actions.includes( 'mailerlite' ) && (
							<MailerLiteOptions
								parentClientId={clientId}
								formInnerBlocks={formInnerBlocks}
								settings={mailerlite}
								save={( value ) => { setMetaAttribute({ ...mailerlite, ...value }, 'mailerlite' ); }}
							/>
						)}

						{actions.includes( 'fluentCRM' ) && (
							<FluentCrmOptions
								parentClientId={clientId}
								formInnerBlocks={formInnerBlocks}
								settings={fluentcrm}
								save={( value ) => setMetaAttribute( { ...fluentcrm, ...value }, 'fluentcrm' )}
							/>
						)}

						{actions.includes( 'sendinblue' ) && (
							<SendinBlueOptions
								parentClientId={clientId}
								formInnerBlocks={formInnerBlocks}
								settings={sendinblue}
								save={( value ) => setMetaAttribute( { ...sendinblue, ...value }, 'sendinblue' )}
							/>
						)}

						{actions.includes( 'mailchimp' ) && (
							<MailchimpOptions
								parentClientId={clientId}
								formInnerBlocks={formInnerBlocks}
								settings={mailchimp}
								save={( value ) => setMetaAttribute( { ...mailchimp, ...value }, 'mailchimp' )}
							/>
						)}

						{actions.includes( 'convertkit' ) && (
							<ConvertKitOptions
								parentClientId={clientId}
								formInnerBlocks={formInnerBlocks}
								settings={convertkit}
								save={( value ) => setMetaAttribute( { ...convertkit, ...value }, 'convertkit' )}
							/>
						)}

						{actions.includes( 'activecampaign' ) && (
							<ActiveCampaignOptions
								parentClientId={clientId}
								formInnerBlocks={formInnerBlocks}
								settings={activecampaign}
								save={( value ) => setMetaAttribute( { ...activecampaign, ...value }, 'activecampaign' )}
							/>
						)}

						{actions.includes( 'webhook' ) && (
							<WebhookOptions
								parentClientId={clientId}
								formInnerBlocks={formInnerBlocks}
								settings={webhook}
								save={( value ) => setMetaAttribute( { ...webhook, ...value }, 'webhook' )}
							/>
						)}

						{actions.includes( 'autoEmail' ) && (
							<AutoEmailOptions
								settings={autoEmail}
								save={( value ) => setMetaAttribute( { ...autoEmail, ...value }, 'autoEmail' )}
							/>
						)}

						{actions.includes( 'entry' ) && (
							<DbEntryOptions
								settings={entry}
								save={( value ) => setMetaAttribute( { ...entry, ...value }, 'entry' )}
							/>
						)}
						<div className="bt-sidebar-settings-spacer"></div>
						{/*<BasePanelBody*/}
						{/*	panelName={'bb-advanced-form-spam'}*/}
						{/*	title={__( 'Spam Prevention', 'gutenam-blocks' )}*/}
						{/*	initialOpen={false}*/}
						{/*>*/}
						{/*	*/}
						{/*</BasePanelBody>*/}
						<BasePanelBody
							title={__( 'Message Settings', 'gutenam-blocks' )}
							initialOpen={false}
							panelName={'bb-form-message'}
						>
							<MessageOptions setAttributes={setMetaAttribute} messages={ messages } />
						</BasePanelBody>
					</>
				}

				{( activeTab === 'style' ) &&
					<>

						<BasePanelBody
							title={__( 'Input Fields', 'gutenam-blocks' )}
							initialOpen={true}
							panelName={'bb-form-field-styles'}
						>
							<FieldStyles setMetaAttribute={setMetaAttribute} inputFont={inputFont} style={style} useFormMeta={ useFormMeta }/>
						</BasePanelBody>

						{/* Label Styles*/}
						<BasePanelBody
							title={__( 'Labels', 'gutenam-blocks' )}
							initialOpen={false}
							panelName={'bb-form-label-styles'}
						>
							<LabelOptions styleAttribute={style} setAttributes={setMetaAttribute} labelFont={labelFont}/>
						</BasePanelBody>
						{/* Label Styles*/}
						<BasePanelBody
							title={__( 'Radio/Checkbox Labels', 'gutenam-blocks' )}
							initialOpen={false}
							panelName={'bb-form-radio-label-styles'}
						>
							<RadioLabelOptions setAttributes={setMetaAttribute} radioLabelFont={radioLabelFont}/>
						</BasePanelBody>
						{/* Help Text Styles*/}
						<BasePanelBody
							title={__( 'Help Text', 'gutenam-blocks' )}
							initialOpen={false}
							panelName={'bb-form-help-styles'}
						>
							<HelpTextOptions setAttributes={setMetaAttribute} helpFont={helpFont}/>
						</BasePanelBody>

						<BasePanelBody
							title={__( 'Message Styling', 'gutenam-blocks' )}
							initialOpen={false}
							panelName={'bb-form-message'}
						>
							<MessageStyling setMetaAttribute={setMetaAttribute} useFormMeta={ useFormMeta } />
						</BasePanelBody>
					</>
				}

				{( activeTab === 'advanced' ) &&
					<>
						<BasePanelBody panelName={'bb-row-padding'}>
							<ResponsiveMeasureRangeControl
								label={__('Padding', 'gutenam-blocks')}
								value={padding}
								tabletValue={tabletPadding}
								mobileValue={mobilePadding}
								onChange={(value) => {
									setMetaAttribute( value, 'padding' );
								}}
								onChangeTablet={(value) => {
									setMetaAttribute( value, 'tabletPadding' );
								}}
								onChangeMobile={(value) => {
									setMetaAttribute( value, 'mobilePadding' );
								}}
								min={0}
								max={(paddingUnit === 'em' || paddingUnit === 'rem' ? 24 : 200)}
								step={(paddingUnit === 'em' || paddingUnit === 'rem' ? 0.1 : 1)}
								unit={paddingUnit}
								units={['px', 'em', 'rem', '%']}
								onUnit={(value) => setMetaAttribute( value, 'paddingUnit' )}
								onMouseOver={paddingMouseOver.onMouseOver}
								onMouseOut={paddingMouseOver.onMouseOut}
							/>
							<ResponsiveMeasureRangeControl
								label={__('Margin', 'gutenam-blocks')}
								value={margin}
								tabletValue={tabletMargin}
								mobileValue={mobileMargin}
								onChange={(value) => {
									setMetaAttribute( value, 'margin' );
								}}
								onChangeTablet={(value) => {
									setMetaAttribute( value, 'tabletMargin' );
								}}
								onChangeMobile={(value) => {
									setMetaAttribute( value, 'mobileMargin' );
								}}
								min={(marginUnit === 'em' || marginUnit === 'rem' ? -12 : -200)}
								max={(marginUnit === 'em' || marginUnit === 'rem' ? 24 : 200)}
								step={(marginUnit === 'em' || marginUnit === 'rem' ? 0.1 : 1)}
								unit={marginUnit}
								units={['px', 'em', 'rem', '%', 'vh']}
								onUnit={(value) => setMetaAttribute( value, 'marginUnit' )}
								onMouseOver={marginMouseOver.onMouseOver}
								onMouseOut={marginMouseOver.onMouseOut}
							/>
						</BasePanelBody>
						<div className="bt-sidebar-settings-spacer"></div>
						<BasePanelBody
							initialOpen={true}
							panelName={ 'bb-adv-form-max-width' }
						>
							<BackgroundTypeControl
								label={ __( 'Background Type', 'gutenam-blocks' ) }
								type={ background?.backgroundType ? background.backgroundType : 'normal' }
								onChange={ value => saveBackgroundStyle( { backgroundType: value } ) }
								allowedTypes={ [ 'normal', 'gradient' ] }
							/>
							{'gradient' !== background?.backgroundType && (
								<PopColorControl
									label={__( 'Background', 'gutenam-blocks' )}
									value={( background?.background ? background.background : '' )}
									default={''}
									onChange={ ( value ) => {
										saveBackgroundStyle( { background: value } );
									}}
								/>
							)}
							{'gradient' === background?.backgroundType && (
								<GradientControl
									value={ background?.gradient }
									onChange={ value => {
										saveBackgroundStyle( { gradient: value } );
									}}
									gradients={ [] }
								/>
							)}
							<ResponsiveRangeControls
								label={__( 'Max Width', 'gutenam-blocks' )}
								value={ ( maxWidth[ 0 ] !== '' ? parseInt( maxWidth[ 0 ] ) : '' ) }
								onChange={ ( value ) => {
									value = value ? value : '';
									setMetaAttribute( [ value.toString(), maxWidth[ 1 ], maxWidth[ 2 ] ], 'maxWidth' );
								}}
								tabletValue={ ( maxWidth[ 1 ] !== '' ? parseInt( maxWidth[ 1 ] ) : '' ) }
								onChangeTablet={( value ) => {
									value = value ? value : '';
									setMetaAttribute( [ maxWidth[ 0 ], value.toString(), maxWidth[ 2 ] ], 'maxWidth' );
								}}
								mobileValue={ ( maxWidth[ 2 ] !== '' ? parseInt( maxWidth[ 2 ] ) : '' ) }
								onChangeMobile={( value ) => {
									value = value ? value : '';
									setMetaAttribute( [ maxWidth[ 0 ], maxWidth[ 1 ], value.toString() ], 'maxWidth' );
								}}
								min={0}
								max={( maxWidthUnit === 'px' ? 2000 : 100 )}
								step={1}
								reset={ () => setMetaAttribute( [ '', '', '' ], 'maxWidth' ) }
								unit={maxWidthUnit ? maxWidthUnit : '%'}
								onUnit={( value ) => {
									setMetaAttribute( value, 'maxWidthUnit' );
								}}
								units={[ 'px', '%', 'vw' ]}
							/>
						</BasePanelBody>
					</>
				}

			</InspectorControls>
			<InspectorAdvancedControls>
				<ToggleControl
					label={ __( 'Form Styles', 'gutenam-blocks' ) }
					help={ __( 'Only disable if you intend to control form styles through custom css or theme', 'gutenam-blocks' ) }
					checked={ undefined !== style?.basicStyles ? style.basicStyles : true }
					onChange={( value ) => { setMetaAttribute( { ...style, ...{ basicStyles: value } }, 'style') }}
				/>
			</InspectorAdvancedControls>
			<BackendStyles uniqueID={uniqueID} useFormMeta={useFormMeta} previewDevice={previewDevice} inputFont={inputFont} fieldStyle={style} labelStyle={labelFont} helpStyle={helpFont} radioLabelFont={radioLabelFont} />

			<div {...innerBlocksProps} />
			<SpacingVisualizer
				style={ {
					marginLeft: ( undefined !== previewMarginLeft ? getSpacingOptionOutput( previewMarginLeft, marginUnit ) : undefined ),
					marginRight: ( undefined !== previewMarginRight ? getSpacingOptionOutput( previewMarginRight, marginUnit ) : undefined ),
					marginTop: ( undefined !== previewMarginTop ? getSpacingOptionOutput( previewMarginTop, marginUnit ) : undefined ),
					marginBottom: ( undefined !== previewMarginBottom ? getSpacingOptionOutput( previewMarginBottom, marginUnit ) : undefined ),
				} }
				type="inside"
				forceShow={ paddingMouseOver.isMouseOver }
				spacing={ [ getSpacingOptionOutput( previewPaddingTop, paddingUnit ), getSpacingOptionOutput( previewPaddingRight, paddingUnit ), getSpacingOptionOutput( previewPaddingBottom, paddingUnit ), getSpacingOptionOutput( previewPaddingLeft, paddingUnit ) ] }
			/>
			<SpacingVisualizer
				type="inside"
				forceShow={ marginMouseOver.isMouseOver }
				spacing={ [ getSpacingOptionOutput( previewMarginTop, marginUnit ), getSpacingOptionOutput( previewMarginRight, marginUnit ), getSpacingOptionOutput( previewMarginBottom, marginUnit ), getSpacingOptionOutput( previewMarginLeft, marginUnit ) ] }
			/>

		</>
	);
}
export default ( EditInner );

function useFormProp( prop ) {
	return useEntityProp( 'postType', 'base_form', prop );
}

function useFormMeta( key ) {
	const [ meta, setMeta ] = useFormProp( 'meta' );

	return [
		meta[ key ],
		useCallback(
			( newValue ) => {
				setMeta( { ...meta, [ key ]: newValue } );
			},
			[ key, setMeta ],
		),
	];
}
