/**
 * Internal dependencies
 */
import FormFieldLabel from '../../label';

/**
 * WordPress dependencies
 */
import { TextControl, TextareaControl, SelectControl, ToggleControl } from '@wordpress/components';
import { __ } from '@wordpress/i18n';
import { dateI18n } from '@wordpress/date';
import { InspectorControls, useBlockProps } from '@wordpress/block-editor';
import { useSelect, useDispatch } from '@wordpress/data';
import { BasePanelBody, InspectorControlTabs, ResponsiveRangeControls, FormInputControl, SelectParentBlock } from '@base/components';
import {
	useEffect,
	useState,
	useMemo,
} from '@wordpress/element';
import {
	getUniqueId,
	getPreviewSize,
} from '@base/helpers';
import classNames from 'classnames';
import { DuplicateField, FieldBlockAppender, FieldName } from '../../components';

function FieldDate( { attributes, setAttributes, isSelected, clientId, context, name } ) {
	const { uniqueID, required, label, showLabel, defaultValue, helpText, ariaDescription, maxWidth, maxWidthUnit, minWidth, minWidthUnit, defaultParameter, placeholder, auto, inputName, requiredMessage, baseDynamic } = attributes;
	const [ activeTab, setActiveTab ] = useState( 'general' );
	const { addUniqueID } = useDispatch( 'baseblocks/data' );
	const { isUniqueID, isUniqueBlock, previewDevice } = useSelect(
		( select ) => {
			return {
				isUniqueID: ( value ) => select( 'baseblocks/data' ).isUniqueID( value ),
				isUniqueBlock: ( value, clientId ) => select( 'baseblocks/data' ).isUniqueBlock( value, clientId ),
				previewDevice: select( 'baseblocks/data' ).getPreviewDeviceType(),
			};
		},
		[ clientId ]
	);

	useEffect( () => {
		let uniqueId = getUniqueId( uniqueID, clientId, isUniqueID, isUniqueBlock );
		setAttributes( { uniqueID: uniqueId } );
		addUniqueID( uniqueId, clientId );
	}, [] );
	const previewMaxWidth = getPreviewSize( previewDevice, ( maxWidth && maxWidth[ 0 ] ? maxWidth[ 0 ] : '' ) , ( maxWidth && maxWidth[ 1 ] ? maxWidth[ 1 ] : '' ), ( maxWidth && maxWidth[ 2 ] ? maxWidth[ 2 ] : '' ) );
	const previewMinWidth = getPreviewSize( previewDevice, ( minWidth && minWidth[ 0 ] ? minWidth[ 0 ] : '' ) , ( minWidth && minWidth[ 1 ] ? minWidth[ 1 ] : '' ), ( minWidth && minWidth[ 2 ] ? minWidth[ 2 ] : '' ) );
	const classes = classNames( {
		'bb-adv-form-field': true,
		'bb-adv-form-infield-type-input': true,
	});
	const blockProps = useBlockProps( {
		className: classes,
		style:{
			maxWidth: '' !== previewMaxWidth ? previewMaxWidth + ( maxWidthUnit ? maxWidthUnit : '%' ) : undefined,
			minWidth: '' !== previewMinWidth ? previewMinWidth + ( minWidthUnit ? minWidthUnit : 'px' ) : undefined,
		}
	} );
	const defaultPreview = useMemo( () => {
		if( defaultValue === "today"){
			return dateI18n( 'Y-m-d', new Date() );
		}
		if ( undefined !== baseDynamic && undefined !== baseDynamic['defaultValue'] && undefined !== baseDynamic['defaultValue']?.enable && '' !== baseDynamic['defaultValue'].enable && true === baseDynamic['defaultValue'].enable ) {
			return baseDynamic?.['defaultValue']?.field ? '{' + baseDynamic['defaultValue'].field + '}' : '';
		}
		return attributes?.defaultValue ? attributes.defaultValue : '';
	}, [ baseDynamic, defaultValue ] );
	return (
		<>
			<style>
				{ isSelected && (
					<>
						{ `.block-editor-block-popover__inbetween-container .block-editor-block-list__insertion-point.is-with-inserter { display: none }` };
					</>
				)}
			</style>
			<div {...blockProps}>
				<DuplicateField
					clientId={ clientId }
					name={name}
					attributes={ attributes }
				/>
				<InspectorControls>
					<SelectParentBlock
						label={ __( 'View Form Settings', 'gutenam-blocks' ) }
						clientId={ clientId }
						parentSlug={ 'base/advanced-form' }
					/>
					<InspectorControlTabs
						panelName={'advanced-form-date-general'}
						setActiveTab={ ( value ) => setActiveTab( value ) }
						activeTab={ activeTab }
						allowedTabs={ [ 'general', 'advanced' ] }
					/>
					{ ( activeTab === 'general' ) &&
						<>
							<BasePanelBody
								title={__( 'Field Controls', 'gutenam-blocks' )}
								initialOpen={true}
								panelName={ 'bb-adv-form-date-controls' }
							>
								<ToggleControl
									label={__( 'Required', 'gutenam-blocks' )}
									checked={required}
									onChange={( value ) => setAttributes( { required: value } )}
								/>
								<TextControl
									label={__( 'Field Label', 'gutenam-blocks' )}
									value={label}
									onChange={( value ) => setAttributes( { label: value } )}
								/>
								<ToggleControl
									label={__( 'Show Label', 'gutenam-blocks' )}
									checked={showLabel}
									onChange={( value ) => setAttributes( { showLabel: value } )}
								/>
								<TextareaControl
									label={__( 'Description', 'gutenam-blocks' )}
									help={ __( 'This will be displayed under the input and can be used to provide direction on how the field should be filled out.', 'gutenam-blocks' )}
									value={helpText}
									onChange={( value ) => setAttributes( { helpText: value } )}
								/>
								<TextControl
									label={__( 'Field Placeholder', 'gutenam-blocks' )}
									value={placeholder}
									onChange={( value ) => setAttributes( { placeholder: value } )}
								/>
								<FormInputControl
									label={__( 'Default Value', 'gutenam-blocks' )}
									value={defaultValue}
									preview={ defaultPreview }
									onChange={( value ) => setAttributes( { defaultValue: value } )}
									dynamicAttribute={'defaultValue'}
									allowClear={true}
									isSelected={ isSelected }
									attributes={ attributes }
									setAttributes={ setAttributes }
									name={ name }
									clientId={ clientId }
									context={ context }
								/>
								<em>{ __( 'Set to "today" to fill with the current date', 'gutenam-blocks') }</em>
							</BasePanelBody>
						</>
					}
					{ ( activeTab === 'advanced' ) &&
						<>
							<BasePanelBody
								title={__( 'Field Width', 'gutenam-blocks' )}
								initialOpen={true}
								panelName={ 'bb-adv-form-date-width' }
							>
								<ResponsiveRangeControls
									label={__( 'Max Width', 'gutenam-blocks' )}
									value={( undefined !== maxWidth && undefined !== maxWidth[ 0 ] ? maxWidth[ 0 ] : '' )}
									onChange={value => {
										setAttributes( { maxWidth: [ value, ( undefined !== maxWidth && undefined !== maxWidth[ 1 ] ? maxWidth[ 1 ] : '' ), ( undefined !== maxWidth && undefined !== maxWidth[ 2 ] ? maxWidth[ 2 ] : '' ) ] } );
									}}
									tabletValue={( undefined !== maxWidth && undefined !== maxWidth[ 1 ] ? maxWidth[ 1 ] : '' )}
									onChangeTablet={( value ) => {
										setAttributes( { maxWidth: [ ( undefined !== maxWidth && undefined !== maxWidth[ 0 ] ? maxWidth[ 0 ] : '' ), value, ( undefined !== maxWidth && undefined !== maxWidth[ 2 ] ? maxWidth[ 2 ] : '' ) ] } );
									}}
									mobileValue={( undefined !== maxWidth && undefined !== maxWidth[ 2 ] ? maxWidth[ 2 ] : '' )}
									onChangeMobile={( value ) => {
										setAttributes( { maxWidth: [ ( undefined !== maxWidth && undefined !== maxWidth[ 0 ] ? maxWidth[ 0 ] : '' ), ( undefined !== maxWidth && undefined !== maxWidth[ 1 ] ? maxWidth[ 1 ] : '' ), value ] } );
									}}
									min={0}
									max={( maxWidthUnit === 'px' ? 2000 : 100 )}
									step={1}
									unit={maxWidthUnit ? maxWidthUnit : '%'}
									onUnit={( value ) => {
										setAttributes( { maxWidthUnit: value } );
									}}
									units={[ 'px', '%', 'vw' ]}
								/>
								<ResponsiveRangeControls
									label={__( 'Min Width', 'gutenam-blocks' )}
									value={( undefined !== minWidth && undefined !== minWidth[ 0 ] ? minWidth[ 0 ] : '' )}
									onChange={value => {
										setAttributes( { minWidth: [ value, ( undefined !== minWidth && undefined !== minWidth[ 1 ] ? minWidth[ 1 ] : '' ), ( undefined !== minWidth && undefined !== minWidth[ 2 ] ? minWidth[ 2 ] : '' ) ] } );
									}}
									tabletValue={( undefined !== minWidth && undefined !== minWidth[ 1 ] ? minWidth[ 1 ] : '' )}
									onChangeTablet={( value ) => {
										setAttributes( { minWidth: [ ( undefined !== minWidth && undefined !== minWidth[ 0 ] ? minWidth[ 0 ] : '' ), value, ( undefined !== minWidth && undefined !== minWidth[ 2 ] ? minWidth[ 2 ] : '' ) ] } );
									}}
									mobileValue={( undefined !== minWidth && undefined !== minWidth[ 2 ] ? minWidth[ 2 ] : '' )}
									onChangeMobile={( value ) => {
										setAttributes( { minWidth: [ ( undefined !== minWidth && undefined !== minWidth[ 0 ] ? minWidth[ 0 ] : '' ), ( undefined !== minWidth && undefined !== minWidth[ 1 ] ? minWidth[ 1 ] : '' ), value ] } );
									}}
									min={0}
									max={( minWidthUnit === 'px' ? 2000 : 100 )}
									step={1}
									unit={minWidthUnit ? minWidthUnit : 'px'}
									onUnit={( value ) => {
										setAttributes( { minWidthUnit: value } );
									}}
									units={[ 'px', '%', 'vw' ]}
								/>
							</BasePanelBody>
							<BasePanelBody
								title={__( 'Extra Settings', 'gutenam-blocks' )}
								initialOpen={false}
								panelName={ 'bb-adv-form-date-extra-settings' }
							>
								<FieldName
									value={inputName}
									uniqueID={uniqueID}
									onChange={( value ) => setAttributes( { inputName: value.replace(/[^a-z0-9-_]/gi, '') } ) }
								/>
								<SelectControl
									label={__( 'Field Auto Fill', 'gutenam-blocks' )}
									value={ auto }
									options={[
										{ value: '', label: __( 'Default', 'gutenam-blocks' ) },
										{ value: 'name', label: __( 'Name', 'gutenam-blocks' ) },
										{ value: 'given-name', label: __( 'First Name', 'gutenam-blocks' ) },
										{ value: 'family-name', label: __( 'Last Name', 'gutenam-blocks' ) },
										{ value: 'email', label: __( 'Email', 'gutenam-blocks' ) },
										{ value: 'organization', label: __( 'Organization', 'gutenam-blocks' ) },
										{ value: 'street-address', label: __( 'Street Address', 'gutenam-blocks' ) },
										{ value: 'address-line1', label: __( 'Address Line 1', 'gutenam-blocks' ) },
										{ value: 'address-line2', label: __( 'Address Line 1', 'gutenam-blocks' ) },
										{ value: 'country-name', label: __( 'Country Name', 'gutenam-blocks' ) },
										{ value: 'postal-code', label: __( 'Postal Code', 'gutenam-blocks' ) },
										{ value: 'tel', label: __( 'Telephone', 'gutenam-blocks' ) },
										{ value: 'off', label: __( 'Off', 'gutenam-blocks' ) },
									]}
									onChange={( value ) => setAttributes( { auto: value } )}
								/>
								<TextControl
									label={__( 'Input aria description', 'gutenam-blocks' )}
									value={ariaDescription}
									onChange={( value ) => setAttributes( { ariaDescription: value } )}
									help={ __( 'This content will be hidden by default and exposed to screen readers as the aria-describedby attribute for this form field. Note that the normal description field will no longer be used for aria-describedby.', 'gutenam-blocks' ) }
								/>
								{ required && (
									<TextControl
										label={__( 'Field error message when required', 'gutenam-blocks' )}
										value={requiredMessage}
										onChange={( value ) => setAttributes( { requiredMessage: value } )}
										placeholder={( undefined !== label ? label : '' ) + ' ' + __( 'is required', 'gutenam-blocks' )}
									/>
								)}
								<TextControl
									label={__( 'Populate with Parameter', 'gutenam-blocks' )}
									help={ __( 'Enter a parameter that can be used in the page url to dynamically populate the field.', 'gutenam-blocks' ) }
									value={defaultParameter}
									onChange={( value ) => setAttributes( { defaultParameter: value } )}
								/>
							</BasePanelBody>
						</>
					}
				</InspectorControls>
				<>
					<FormFieldLabel
						required={required}
						label={label}
						showLabel={showLabel}
						setAttributes={setAttributes}
						isSelected={isSelected}
						name={name}
					/>
					<input
						type={'date'}
						className={'bb-field'}
						value={ defaultPreview }
						placeholder={placeholder}
						onChange={( value ) => false}
					/>
					{helpText && <span className="bb-adv-form-help">{helpText}</span>}
				</>
				<FieldBlockAppender inline={ true } className="bb-custom-inbetween-inserter" getRoot={ clientId } />
			</div>
		</>
	);
}

export default FieldDate;
