/**
 * Internal dependencies
 */

/**
 * WordPress dependencies
 */
import { TextControl } from '@wordpress/components';
import { __ } from '@wordpress/i18n';
import { InspectorControls, useBlockProps } from '@wordpress/block-editor';
import { useSelect, useDispatch } from '@wordpress/data';
import { BasePanelBody, InspectorControlTabs, FormInputControl, SelectParentBlock } from '@base/components';
import {
	useEffect,
	useState,
	useMemo,
} from '@wordpress/element';
import { getUniqueId } from '@base/helpers';
import classNames from 'classnames';
import { DuplicateField, FieldBlockAppender, FieldName } from '../../components';

function FieldHidden( { attributes, setAttributes, isSelected, clientId, context, name } ) {
	const { uniqueID, label, defaultValue, defaultParameter, inputName, baseDynamic } = attributes;
	const [ activeTab, setActiveTab ] = useState( 'general' );
	const { addUniqueID } = useDispatch( 'baseblocks/data' );
	const { isUniqueID, isUniqueBlock, previewDevice } = useSelect(
		( select ) => {
			return {
				isUniqueID: ( value ) => select( 'baseblocks/data' ).isUniqueID( value ),
				isUniqueBlock: ( value, clientId ) => select( 'baseblocks/data' ).isUniqueBlock( value, clientId ),
				previewDevice: select( 'baseblocks/data' ).getPreviewDeviceType(),
			};
		},
		[ clientId, inputName ]
	);

	useEffect( () => {
		let uniqueId = getUniqueId( uniqueID, clientId, isUniqueID, isUniqueBlock );
		setAttributes( { uniqueID: uniqueId } );
		addUniqueID( uniqueId, clientId );
	}, [] );
	const classes = classNames( {
		'bb-adv-form-field': true,
	});
	const blockProps = useBlockProps( {
		className: classes
	} );
	const defaultPreview = useMemo( () => {
		if ( undefined !== baseDynamic && undefined !== baseDynamic['defaultValue'] && undefined !== baseDynamic['defaultValue']?.enable && '' !== baseDynamic['defaultValue'].enable && true === baseDynamic['defaultValue'].enable ) {
			return baseDynamic?.['defaultValue']?.field ? '{' + baseDynamic['defaultValue'].field + '}' : '';
		}
		return attributes?.defaultValue ? attributes.defaultValue : '';
	}, [ baseDynamic, defaultValue ] );

	return (
		<>
			<style>
				{ isSelected && (
					<>
						{ `.block-editor-block-popover__inbetween-container .block-editor-block-list__insertion-point.is-with-inserter { display: none }` };
					</>
				)}
			</style>
			<div {...blockProps}>
				<DuplicateField
					clientId={ clientId }
					name={name}
					attributes={ attributes }
				/>
				<InspectorControls>
					<SelectParentBlock
						label={ __( 'View Form Settings', 'gutenam-blocks' ) }
						clientId={ clientId }
						parentSlug={ 'base/advanced-form' }
					/>
					<InspectorControlTabs
						panelName={'advanced-form-hidden-general'}
						setActiveTab={ ( value ) => setActiveTab( value ) }
						activeTab={ activeTab }
						allowedTabs={ [ 'general', 'advanced' ] }
					/>
					{ ( activeTab === 'general' ) &&
						<>
							<BasePanelBody
								title={__( 'Field Controls', 'gutenam-blocks' )}
								initialOpen={true}
								panelName={ 'bb-adv-form-hidden-controls' }
							>
								<TextControl
									label={__( 'Field Label', 'gutenam-blocks' )}
									value={label}
									onChange={( value ) => setAttributes( { label: value } )}
								/>
								<FormInputControl
									label={__( 'Default Value', 'gutenam-blocks' )}
									value={defaultValue}
									preview={ defaultPreview }
									onChange={( value ) => setAttributes( { defaultValue: value } )}
									dynamicAttribute={'defaultValue'}
									allowClear={true}
									isSelected={ isSelected }
									attributes={ attributes }
									setAttributes={ setAttributes }
									name={ name }
									clientId={ clientId }
									context={ context }
								/>
							</BasePanelBody>
						</>
					}
					{ ( activeTab === 'advanced' ) &&
						<>
							<BasePanelBody
								title={__( 'Extra Settings', 'gutenam-blocks' )}
								initialOpen={false}
								panelName={ 'bb-adv-form-hidden-extra-settings' }
							>
								<FieldName
									value={inputName}
									uniqueID={uniqueID}
									onChange={( value ) => setAttributes( { inputName: value.replace(/[^a-z0-9-_]/gi, '') } ) }
								/>
								<TextControl
									label={__( 'Populate with Parameter', 'gutenam-blocks' )}
									help={ __( 'Enter a parameter that can be used in the page url to dynamically populate the field.', 'gutenam-blocks' ) }
									value={defaultParameter}
									onChange={( value ) => setAttributes( { defaultParameter: value } )}
								/>
							</BasePanelBody>
						</>
					}
				</InspectorControls>
				<>
					{label === '' ? <em className='bb-hidden-field-label'>Hidden Field</em> : <em className='bb-hidden-field-label'>Hidden Field: {label}</em>}
				</>
				<FieldBlockAppender inline={ true } className="bb-custom-inbetween-inserter" getRoot={ clientId } />
			</div>
		</>
	);
}

export default FieldHidden;
