/**
 * BLOCK: Base Spacer
 */

import { useBlockProps } from '@wordpress/block-editor';

/**
 * External dependencies
 */
import { IconSpanTag } from '@base/components';
/**
 * External dependencies
 */
import classnames from 'classnames';

function Save( { attributes, className } ) {
    const {
        icon,
        link,
        target,
        width,
        title,
        style,
        linkTitle,
        uniqueID,
    } = attributes;

    const classes = classnames( {
        [ `bt-svg-style-${ style }` ]: style,
        'bt-svg-icon-wrap' : true,
        [ `bt-svg-item-${ uniqueID }` ]: uniqueID,
    } );

    const blockProps = useBlockProps.save( {
        className: classes,
    } );

    return (
        <div {...blockProps}>
            { icon && link && (
                <a href={ link } className={ 'bt-svg-icon-link' } target={ ( '_blank' === target ? target : undefined ) } rel={ '_blank' === target ? 'noopener noreferrer' : undefined } aria-label={ ( undefined !== linkTitle && '' !== linkTitle ? linkTitle : undefined ) }>
                    <IconSpanTag name={ icon } strokeWidth={ ( 'fe' === icon.substring( 0, 2 ) ? width : undefined ) } title={ ( title ? title : '' ) } />
                </a>
            ) }
            { icon && ! link && (
                <IconSpanTag name={ icon } strokeWidth={ ( 'fe' === icon.substring( 0, 2 ) ? width : undefined ) } title={ ( title ? title : '' ) } />
            ) }
        </div>
    );
}

export default Save;
