/**
 * BLOCK: Base Spacer
 */

import { useBlockProps } from '@wordpress/block-editor';

/**
 * External dependencies
 */
import classnames from 'classnames';
import { BaseColorOutput } from '@base/helpers';
import SvgPattern from './svg-pattern';

function Save( { attributes } ) {
	const {
		className,
		blockAlignment,
		dividerEnable,
		dividerStyle,
		hAlign,
		dividerColor,
		dividerOpacity,
		uniqueID,
		rotate,
		strokeWidth,
		strokeGap,
		tabletHAlign,
		mobileHAlign,
		vsdesk,
		vstablet,
		vsmobile,
	} = attributes;

	const innerSpacerClasses = classnames( {
		'bt-block-spacer'                            : true,
		[ `bt-block-spacer-halign-${hAlign}` ]       : hAlign,
		[ `bt-block-spacer-thalign-${tabletHAlign}` ]: tabletHAlign,
		[ `bt-block-spacer-malign-${mobileHAlign}` ] : mobileHAlign,
	} );

	const blockProps = useBlockProps.save( {
		className: classnames( {
			[ `align${( blockAlignment ? blockAlignment : 'none' )}` ]: true,
			[ `bt-block-spacer-${uniqueID}` ]                         : uniqueID,
			'kvs-lg-false'                                            : vsdesk !== 'undefined' && vsdesk,
			'kvs-md-false'                                            : vstablet !== 'undefined' && vstablet,
			'kvs-sm-false'                                            : vsmobile !== 'undefined' && vsmobile,
		},
			className
		),
	} );

	return (
		<div {...blockProps}>
			<div className={innerSpacerClasses}>
				{dividerEnable && (
					<>
						{dividerStyle === 'stripe' && (
							<span className="bt-divider-stripe">
									<SvgPattern uniqueID={uniqueID} color={BaseColorOutput( dividerColor )} opacity={dividerOpacity} rotate={rotate} strokeWidth={strokeWidth}
												strokeGap={strokeGap}/>
								</span>
						)}
						{dividerStyle !== 'stripe' && (
							<hr className="bt-divider"/>
						)}
					</>
				)}
			</div>
		</div>
	);
}

export default Save;
