/**
 * BLOCK: Base Tabs
 */
import classnames from 'classnames';
import { times } from 'lodash';
import { IconSpanTag } from '@base/components';

import {
	InnerBlocks,
	RichText,
	useBlockProps
} from '@wordpress/block-editor';

/**
 * Internal block libraries
 */
import { __, sprintf } from '@wordpress/i18n';

function BaseTabsSave( { attributes } ) {

	const stripStringRender = ( string ) => {
		return string.toLowerCase().replace( /[^0-9a-z-]/g, '' );
	};

	const { tabCount, blockAlignment, currentTab, mobileLayout, layout, tabletLayout, uniqueID, titles, iSize, maxWidth, tabAlignment, startTab, enableSubtitle, widthType, tabWidth } = attributes;
	const layoutClass = ( !layout ? 'tabs' : layout );
	const tabLayoutClass = ( !tabletLayout ? 'inherit' : tabletLayout );
	const mobileLayoutClass = ( !mobileLayout ? 'inherit' : mobileLayout );
	const accordionClass = ( ( mobileLayout && 'accordion' === mobileLayout ) || ( tabletLayout && 'accordion' === tabletLayout ) ? 'bt-create-accordion' : '' );
	const classId = ( !uniqueID ? 'notset' : uniqueID );
	const theTabAlignment = ( tabAlignment ? tabAlignment : 'left' );
	const classes = classnames( `align${ ( blockAlignment ? blockAlignment : 'none' ) }` );
	const activeTab = ( startTab ? startTab : currentTab );
	const innerClasses = classnames( `bt-tabs-wrap bt-tabs-id${classId} bt-tabs-has-${tabCount}-tabs bt-active-tab-${activeTab} bt-tabs-layout-${layoutClass} bt-tabs-tablet-layout-${tabLayoutClass} bt-tabs-mobile-layout-${mobileLayoutClass} bt-tab-alignment-${theTabAlignment} ${accordionClass}` );

	const renderTitles = ( index ) => {
		const backupAnchor = `tab-${( titles[ index ] && titles[ index ].text ? stripStringRender( titles[ index ].text.toString() ) : stripStringRender( __( 'Tab' ) + ( 1 + index ) ) )}`;
		return (
			<li id={( titles[ index ] && titles[ index ].anchor ? titles[ index ].anchor : backupAnchor )}
				className={`bt-title-item bt-title-item-${1 + index} bt-tabs-svg-show-${( titles[ index ] && titles[ index ].onlyIcon ? 'only' : 'always' )} bt-tabs-icon-side-${( titles[ index ] && titles[ index ].iconSide ? titles[ index ].iconSide : 'right' )} bt-tab-title-${( 1 + index === activeTab ? 'active' : 'inactive' )}${( enableSubtitle ? ' bb-tabs-have-subtitle' : '' )}`}>
				<a href={`#${( titles[ index ] && titles[ index ].anchor ? titles[ index ].anchor : backupAnchor )}`} data-tab={1 + index} className={`bt-tab-title bt-tab-title-${1 + index} `}>
					{titles[ index ] && titles[ index ].icon && 'right' !== titles[ index ].iconSide && (
						<IconSpanTag className={`bt-tab-svg-icon bt-tab-svg-icon-${titles[ index ].icon} bt-title-svg-side-${titles[ index ].iconSide}`} name={titles[ index ].icon}
									 size={( !iSize ? '14' : iSize )}/>
					)}
					{( !enableSubtitle || ( undefined !== titles[ index ] && undefined === titles[ index ].subText ) || ( undefined !== titles[ index ] && undefined !== titles[ index ].subText && '' === titles[ index ].subText ) ) && (
						<RichText.Content
							tagName="span"
							value={( titles[ index ] && titles[ index ].text ? titles[ index ].text : sprintf( __( 'Tab %d' ), ( 1 + index ) ) )}
							className={'bt-title-text'}
						/>
					)}
					{enableSubtitle && titles[ index ] && undefined !== titles[ index ].subText && '' !== titles[ index ].subText && (
						<div className="bb-tab-titles-wrap">
							<RichText.Content
								tagName="span"
								value={( titles[ index ] && titles[ index ].text ? titles[ index ].text : sprintf( __( 'Tab %d' ), ( 1 + index ) ) )}
								className={'bt-title-text'}
							/>
							<RichText.Content
								tagName="span"
								value={titles[ index ].subText}
								className={'bt-title-sub-text'}
							/>
						</div>
					)}
					{titles[ index ] && titles[ index ].icon && 'right' === titles[ index ].iconSide && (
						<IconSpanTag className={`bt-tab-svg-icon bt-tab-svg-icon-${titles[ index ].icon} bt-title-svg-side-${titles[ index ].iconSide}`} name={titles[ index ].icon}
									 size={( !iSize ? '14' : iSize )}/>
					)}
				</a>
			</li>
		);
	};

	const blockProps = useBlockProps.save( {
		className: classes
	} );

	return (
		<div {...blockProps}>
			<div className={innerClasses}>
				<ul className={`bt-tabs-title-list${( 'tabs' === layout && widthType === 'percent' ? ' bb-tabs-list-columns bb-tab-title-columns-' + tabWidth[ 0 ] : '' )}`}>
					{times( tabCount, n => renderTitles( n ) )}
				</ul>
				<div className="bt-tabs-content-wrap">
					<InnerBlocks.Content/>
				</div>
			</div>
		</div>
	);

}

export default BaseTabsSave;
