/**
 * WordPress dependencies
 */
import { __ } from '@wordpress/i18n';
import { Button, withFilters, Popover, ExternalLink } from '@wordpress/components';
import { createRef, Fragment, Component } from '@wordpress/element';
import { debounce } from 'lodash';
import { applyFilters } from '@wordpress/hooks'
import { useState } from '@wordpress/element';

/**
 * External dependencies
 */
import { dynamic } from '@base/icons';

function DynamicFormInputControl() {
    const [popoverAnchor, setPopoverAnchor] = useState();
    const [isVisible, setIsVisible] = useState(false);
    const toggleVisible = () => {
        setIsVisible( ! isVisible );
    }
    const debounceToggle = debounce( toggleVisible, 100 );
	return (
		<div className="bb-dynamic-form-input-sidebar-wrap">
			<Button
				className="bb-dynamic-form-input-sidebar"
				icon={ dynamic }
				onClick={ () => debounceToggle() }
				ref={ setPopoverAnchor }
				isPressed={ isVisible }
				aria-haspopup="true"
				aria-expanded={ isVisible }
				label={  __( 'Dynamic Content', 'gutenam-blocks' ) }
				showTooltip={ true }
			/>
            {isVisible &&
                <Popover
                    headerTitle={ __('Select Dynamic Source', 'gutenam-blocks') }
                    noArrow={false}
                    onClose={debounceToggle}
                    placement="bottom-end"
                    anchor={popoverAnchor}
                    className={ `bb-dynamic-popover`}
                >
					<div className="bb-dynamic-popover-inner-wrap">
						<div className="bb-pro-notice">
							<h2>{ __( 'Dynamic Content', 'gutenam-blocks-pro' ) } </h2>
							<p>{ __( 'Create dynamic sites by populating content from various sources.', 'gutenam-blocks-pro' ) } </p>
							<ExternalLink href={ 'https://avanam.org/base-blocks/pro/?utm_source=in-app&utm_medium=base-blocks&utm_campaign=dynamic-content' }>{ __( 'Upgrade to Pro', 'gutenam-blocks-pro' ) }</ExternalLink>
						</div>
					</div>
				</Popover>
            }
        </div>
    )
}
export default withFilters( 'base.FormInputDynamicControl' )( DynamicFormInputControl );
