/**
 * WordPress dependencies
 */
import DynamicFormInput from '../dynamic-form-input';


import { __ } from '@wordpress/i18n';
import { Button, TextControl } from '@wordpress/components';
import { map, isEqual } from 'lodash';
/**
* WordPress dependencies
*/
import { useInstanceId } from '@wordpress/compose';
import { applyFilters } from '@wordpress/hooks';

/**
 * Import Css
 */
import './editor.scss';
export default function FormInputControl( {
    value,
    onChange,
    label,
    className,
	reset,
	defaultValue = '',
	dynamicAttribute,
	isSelected,
	attributes,
	setAttributes,
	name,
	clientId,
	context,
} ) {
	const instanceId = useInstanceId(FormInputControl );
	const onReset = () => {
		if ( typeof reset === 'function' ){
			reset();
		} else {
			onChange( defaultValue );
		}
	}
	const { baseDynamic } = attributes;
	const hasDynamic = ( undefined !== baseDynamic && undefined !== baseDynamic[dynamicAttribute] && undefined !== baseDynamic[dynamicAttribute].enable && '' !== baseDynamic[dynamicAttribute].enable ? baseDynamic[dynamicAttribute].enable : false )
	return (
		<div className={ `components-base-control base-form-input-control base-form-input-control${ instanceId }${ className ? ' ' + className : '' }` }>
			{ label && (
				<div className={ 'base-form-input-control__header' } >
					{ label && (
						<div className="base-form-input-control__title">
							<label className="components-base-control__label">{ label }</label>
							{ reset && (
								<div className='title-reset-wrap'>
									<Button
										className="is-reset is-single"
										label='reset'
										isSmall
										disabled={ ( ( isEqual( defaultValue, value ) ) ? true : false ) }
										icon={ undo }
										onClick={ () => onReset() }
									/>
								</div>
							) }
						</div>
					) }
				</div>
			) }
			<div className={ 'base-controls-content' }>
				{ hasDynamic && (
					<div
						className='base-form-input-control__dynamic__label'
					>
					{ applyFilters(
						'base.formInputDisplay',
						value,
						attributes,
						dynamicAttribute
					) }
					</div>
				) }
				{ ! hasDynamic && (
					<TextControl
						label={''}
						value={ value }
						onChange={( value ) => onChange( value )}
					/>
				) }
				<DynamicFormInput
					dynamicAttribute={ dynamicAttribute }
					isSelected={ isSelected }
					attributes={ attributes }
					setAttributes={ setAttributes }
					name={ name }
					clientId={ clientId }
					context={ context }
				/>
			</div>
        </div>
    )
}